@@ -22,13 +22,15 @@ from ... import errors
 from ... import revision as _mod_revision
 from ... import transport as _mod_transport
 from ...controldir import ControlDir
-from .request import (FailedSmartServerResponse, SmartServerRequest,
-                      SuccessfulSmartServerResponse)
+from .request import (
+    FailedSmartServerResponse,
+    SmartServerRequest,
+    SuccessfulSmartServerResponse,
+)
 
 
 class SmartServerBranchRequest(SmartServerRequest):
-    """Base class for handling common branch request logic.
-    """
+    """Base class for handling common branch request logic."""
 
     def do(self, path, *args):
         """Execute a request for a branch at path.
@@ -62,32 +64,33 @@ class SmartServerLockedBranchRequest(SmartServerBranchRequest):
         processed.  The physical lock state won't be changed.
         """
         # XXX: write a test for LockContention
-        with branch.repository.lock_write(token=repo_token), \
-                branch.lock_write(token=branch_token):
+        with (
+            branch.repository.lock_write(token=repo_token),
+            branch.lock_write(token=branch_token),
+        ):
             return self.do_with_locked_branch(branch, *args)
 
 
 class SmartServerBranchBreakLock(SmartServerBranchRequest):
-
     def do_with_branch(self, branch):
-        """Break a branch lock.
-        """
+        """Break a branch lock."""
         branch.break_lock()
-        return SuccessfulSmartServerResponse((b'ok', ), )
+        return SuccessfulSmartServerResponse(
+            (b"ok",),
+        )
 
 
 class SmartServerBranchGetConfigFile(SmartServerBranchRequest):
-
     def do_with_branch(self, branch):
-        """Return the content of branch.conf
+        """Return the content of branch.conf.
 
         The body is not utf8 decoded - its the literal bytestream from disk.
         """
         try:
-            content = branch.control_transport.get_bytes('branch.conf')
+            content = branch.control_transport.get_bytes("branch.conf")
         except _mod_transport.NoSuchFile:
-            content = b''
-        return SuccessfulSmartServerResponse((b'ok', ), content)
+            content = b""
+        return SuccessfulSmartServerResponse((b"ok",), content)
 
 
 class SmartServerBranchPutConfigFile(SmartServerBranchRequest):
@@ -108,23 +111,22 @@ class SmartServerBranchPutConfigFile(SmartServerBranchRequest):
         return None
 
     def do_body(self, body_bytes):
-        with self._branch.repository.lock_write(token=self._repo_token), \
-                self._branch.lock_write(token=self._branch_token):
-            self._branch.control_transport.put_bytes(
-                'branch.conf', body_bytes)
-        return SuccessfulSmartServerResponse((b'ok', ))
+        with (
+            self._branch.repository.lock_write(token=self._repo_token),
+            self._branch.lock_write(token=self._branch_token),
+        ):
+            self._branch.control_transport.put_bytes("branch.conf", body_bytes)
+        return SuccessfulSmartServerResponse((b"ok",))
 
 
 class SmartServerBranchGetParent(SmartServerBranchRequest):
-
     def do_with_branch(self, branch):
         """Return the parent of branch."""
-        parent = branch._get_parent_location() or ''
-        return SuccessfulSmartServerResponse((parent.encode('utf-8'),))
+        parent = branch._get_parent_location() or ""
+        return SuccessfulSmartServerResponse((parent.encode("utf-8"),))
 
 
 class SmartServerBranchGetTagsBytes(SmartServerBranchRequest):
-
     def do_with_branch(self, branch):
         """Return the _get_tags_bytes for a branch."""
         bytes = branch._get_tags_bytes()
@@ -132,10 +134,10 @@ class SmartServerBranchGetTagsBytes(SmartServerBranchRequest):
 
 
 class SmartServerBranchSetTagsBytes(SmartServerLockedBranchRequest):
-
-    def __init__(self, backing_transport, root_client_path='/', jail_root=None):
+    def __init__(self, backing_transport, root_client_path="/", jail_root=None):
         SmartServerLockedBranchRequest.__init__(
-            self, backing_transport, root_client_path, jail_root)
+            self, backing_transport, root_client_path, jail_root
+        )
         self.locked = False
 
     def do_with_locked_branch(self, branch):
@@ -168,7 +170,6 @@ class SmartServerBranchSetTagsBytes(SmartServerLockedBranchRequest):
 
 
 class SmartServerBranchHeadsToFetch(SmartServerBranchRequest):
-
     def do_with_branch(self, branch):
         """Return the heads-to-fetch for a Branch as two bencoded lists.
 
@@ -177,21 +178,18 @@ class SmartServerBranchHeadsToFetch(SmartServerBranchRequest):
         New in 2.4.
         """
         must_fetch, if_present_fetch = branch.heads_to_fetch()
-        return SuccessfulSmartServerResponse(
-            (list(must_fetch), list(if_present_fetch)))
+        return SuccessfulSmartServerResponse((list(must_fetch), list(if_present_fetch)))
 
 
 class SmartServerBranchRequestGetStackedOnURL(SmartServerBranchRequest):
-
     def do_with_branch(self, branch):
         stacked_on_url = branch.get_stacked_on_url()
-        return SuccessfulSmartServerResponse((b'ok', stacked_on_url.encode('ascii')))
+        return SuccessfulSmartServerResponse((b"ok", stacked_on_url.encode("ascii")))
 
 
 class SmartServerRequestRevisionHistory(SmartServerBranchRequest):
-
     def do_with_branch(self, branch):
-        """Get the revision history for the branch.
+        r"""Get the revision history for the branch.
 
         The revision list is returned as the body content,
         with each revision utf8 encoded and \x00 joined.
@@ -199,14 +197,15 @@ class SmartServerRequestRevisionHistory(SmartServerBranchRequest):
         with branch.lock_read():
             graph = branch.repository.get_graph()
             stop_revisions = (None, _mod_revision.NULL_REVISION)
-            history = list(graph.iter_lefthand_ancestry(
-                branch.last_revision(), stop_revisions))
+            history = list(
+                graph.iter_lefthand_ancestry(branch.last_revision(), stop_revisions)
+            )
         return SuccessfulSmartServerResponse(
-            (b'ok', ), (b'\x00'.join(reversed(history))))
+            (b"ok",), (b"\x00".join(reversed(history)))
+        )
 
 
 class SmartServerBranchRequestLastRevisionInfo(SmartServerBranchRequest):
-
     def do_with_branch(self, branch):
         """Return branch.last_revision_info().
 
@@ -214,11 +213,11 @@ class SmartServerBranchRequestLastRevisionInfo(SmartServerBranchRequest):
         """
         revno, last_revision = branch.last_revision_info()
         return SuccessfulSmartServerResponse(
-            (b'ok', str(revno).encode('ascii'), last_revision))
+            (b"ok", str(revno).encode("ascii"), last_revision)
+        )
 
 
 class SmartServerBranchRequestRevisionIdToRevno(SmartServerBranchRequest):
-
     def do_with_branch(self, branch, revid):
         """Return branch.revision_id_to_revno().
 
@@ -229,13 +228,14 @@ class SmartServerBranchRequestRevisionIdToRevno(SmartServerBranchRequest):
         try:
             dotted_revno = branch.revision_id_to_dotted_revno(revid)
         except errors.NoSuchRevision:
-            return FailedSmartServerResponse((b'NoSuchRevision', revid))
+            return FailedSmartServerResponse((b"NoSuchRevision", revid))
         except errors.GhostRevisionsHaveNoRevno as e:
             return FailedSmartServerResponse(
-                (b'GhostRevisionsHaveNoRevno', e.revision_id,
-                    e.ghost_revision_id))
+                (b"GhostRevisionsHaveNoRevno", e.revision_id, e.ghost_revision_id)
+            )
         return SuccessfulSmartServerResponse(
-            (b'ok', ) + tuple([b'%d' % x for x in dotted_revno]))
+            (b"ok",) + tuple([b"%d" % x for x in dotted_revno])
+        )
 
 
 class SmartServerSetTipRequest(SmartServerLockedBranchRequest):
@@ -249,8 +249,8 @@ class SmartServerSetTipRequest(SmartServerLockedBranchRequest):
         except errors.TipChangeRejected as e:
             msg = e.msg
             if isinstance(msg, str):
-                msg = msg.encode('utf-8')
-            return FailedSmartServerResponse((b'TipChangeRejected', msg))
+                msg = msg.encode("utf-8")
+            return FailedSmartServerResponse((b"TipChangeRejected", msg))
 
 
 class SmartServerBranchRequestSetConfigOption(SmartServerLockedBranchRequest):
@@ -260,8 +260,10 @@ class SmartServerBranchRequestSetConfigOption(SmartServerLockedBranchRequest):
         if not section:
             section = None
         branch._get_config().set_option(
-            value.decode('utf-8'), name.decode('utf-8'),
-            section.decode('utf-8') if section is not None else None)
+            value.decode("utf-8"),
+            name.decode("utf-8"),
+            section.decode("utf-8") if section is not None else None,
+        )
         return SuccessfulSmartServerResponse(())
 
 
@@ -275,32 +277,32 @@ class SmartServerBranchRequestSetConfigOptionDict(SmartServerLockedBranchRequest
         utf8_dict = bencode.bdecode(value_dict)
         value_dict = {}
         for key, value in utf8_dict.items():
-            value_dict[key.decode('utf8')] = value.decode('utf8')
+            value_dict[key.decode("utf8")] = value.decode("utf8")
         if not section:
             section = None
         else:
-            section = section.decode('utf-8')
-        branch._get_config().set_option(value_dict, name.decode('utf-8'), section)
+            section = section.decode("utf-8")
+        branch._get_config().set_option(value_dict, name.decode("utf-8"), section)
         return SuccessfulSmartServerResponse(())
 
 
 class SmartServerBranchRequestSetLastRevision(SmartServerSetTipRequest):
-
     def do_tip_change_with_locked_branch(self, branch, new_last_revision_id):
-        if new_last_revision_id == b'null:':
+        if new_last_revision_id == b"null:":
             branch.set_last_revision_info(0, new_last_revision_id)
         else:
             if not branch.repository.has_revision(new_last_revision_id):
                 return FailedSmartServerResponse(
-                    (b'NoSuchRevision', new_last_revision_id))
+                    (b"NoSuchRevision", new_last_revision_id)
+                )
             branch.generate_revision_history(new_last_revision_id, None, None)
-        return SuccessfulSmartServerResponse((b'ok',))
+        return SuccessfulSmartServerResponse((b"ok",))
 
 
 class SmartServerBranchRequestSetLastRevisionEx(SmartServerSetTipRequest):
-
-    def do_tip_change_with_locked_branch(self, branch, new_last_revision_id,
-                                         allow_divergence, allow_overwrite_descendant):
+    def do_tip_change_with_locked_branch(
+        self, branch, new_last_revision_id, allow_divergence, allow_overwrite_descendant
+    ):
         """Set the last revision of the branch.
 
         New in 1.6.
@@ -329,20 +331,19 @@ class SmartServerBranchRequestSetLastRevisionEx(SmartServerSetTipRequest):
             graph = branch.repository.get_graph()
             if not allow_divergence or do_not_overwrite_descendant:
                 relation = branch._revision_relations(
-                    last_rev, new_last_revision_id, graph)
-                if relation == 'diverged' and not allow_divergence:
-                    return FailedSmartServerResponse((b'Diverged',))
-                if relation == 'a_descends_from_b' and do_not_overwrite_descendant:
-                    return SuccessfulSmartServerResponse(
-                        (b'ok', last_revno, last_rev))
+                    last_rev, new_last_revision_id, graph
+                )
+                if relation == "diverged" and not allow_divergence:
+                    return FailedSmartServerResponse((b"Diverged",))
+                if relation == "a_descends_from_b" and do_not_overwrite_descendant:
+                    return SuccessfulSmartServerResponse((b"ok", last_revno, last_rev))
             new_revno = graph.find_distance_to_null(
-                new_last_revision_id, [(last_rev, last_revno)])
+                new_last_revision_id, [(last_rev, last_revno)]
+            )
             branch.set_last_revision_info(new_revno, new_last_revision_id)
         except errors.GhostRevisionsHaveNoRevno:
-            return FailedSmartServerResponse(
-                (b'NoSuchRevision', new_last_revision_id))
-        return SuccessfulSmartServerResponse(
-            (b'ok', new_revno, new_last_revision_id))
+            return FailedSmartServerResponse((b"NoSuchRevision", new_last_revision_id))
+        return SuccessfulSmartServerResponse((b"ok", new_revno, new_last_revision_id))
 
 
 class SmartServerBranchRequestSetLastRevisionInfo(SmartServerSetTipRequest):
@@ -352,14 +353,12 @@ class SmartServerBranchRequestSetLastRevisionInfo(SmartServerSetTipRequest):
     New in breezy 1.4.
     """
 
-    def do_tip_change_with_locked_branch(self, branch, new_revno,
-                                         new_last_revision_id):
+    def do_tip_change_with_locked_branch(self, branch, new_revno, new_last_revision_id):
         try:
             branch.set_last_revision_info(int(new_revno), new_last_revision_id)
         except errors.NoSuchRevision:
-            return FailedSmartServerResponse(
-                (b'NoSuchRevision', new_last_revision_id))
-        return SuccessfulSmartServerResponse((b'ok',))
+            return FailedSmartServerResponse((b"NoSuchRevision", new_last_revision_id))
+        return SuccessfulSmartServerResponse((b"ok",))
 
 
 class SmartServerBranchRequestSetParentLocation(SmartServerLockedBranchRequest):
@@ -369,57 +368,54 @@ class SmartServerBranchRequestSetParentLocation(SmartServerLockedBranchRequest):
     """
 
     def do_with_locked_branch(self, branch, location):
-        branch._set_parent_location(location.decode('utf-8'))
+        branch._set_parent_location(location.decode("utf-8"))
         return SuccessfulSmartServerResponse(())
 
 
 class SmartServerBranchRequestLockWrite(SmartServerBranchRequest):
-
-    def do_with_branch(self, branch, branch_token=b'', repo_token=b''):
-        if branch_token == b'':
+    def do_with_branch(self, branch, branch_token=b"", repo_token=b""):
+        if branch_token == b"":
             branch_token = None
-        if repo_token == b'':
+        if repo_token == b"":
             repo_token = None
         try:
-            repo_token = branch.repository.lock_write(
-                token=repo_token).repository_token
+            repo_token = branch.repository.lock_write(token=repo_token).repository_token
             try:
-                branch_token = branch.lock_write(
-                    token=branch_token).token
+                branch_token = branch.lock_write(token=branch_token).token
             finally:
                 # this leaves the repository with 1 lock
                 branch.repository.unlock()
         except errors.LockContention:
-            return FailedSmartServerResponse((b'LockContention',))
+            return FailedSmartServerResponse((b"LockContention",))
         except errors.TokenMismatch:
-            return FailedSmartServerResponse((b'TokenMismatch',))
+            return FailedSmartServerResponse((b"TokenMismatch",))
         except errors.UnlockableTransport:
-            return FailedSmartServerResponse((b'UnlockableTransport',))
+            return FailedSmartServerResponse((b"UnlockableTransport",))
         except errors.LockFailed as e:
-            return FailedSmartServerResponse((b'LockFailed',
-                                              str(e.lock).encode('utf-8'), str(e.why).encode('utf-8')))
+            return FailedSmartServerResponse(
+                (b"LockFailed", str(e.lock).encode("utf-8"), str(e.why).encode("utf-8"))
+            )
         if repo_token is None:
-            repo_token = b''
+            repo_token = b""
         else:
             branch.repository.leave_lock_in_place()
         branch.leave_lock_in_place()
         branch.unlock()
-        return SuccessfulSmartServerResponse((b'ok', branch_token, repo_token))
+        return SuccessfulSmartServerResponse((b"ok", branch_token, repo_token))
 
 
 class SmartServerBranchRequestUnlock(SmartServerBranchRequest):
-
     def do_with_branch(self, branch, branch_token, repo_token):
         try:
             with branch.repository.lock_write(token=repo_token):
                 branch.lock_write(token=branch_token)
         except errors.TokenMismatch:
-            return FailedSmartServerResponse((b'TokenMismatch',))
+            return FailedSmartServerResponse((b"TokenMismatch",))
         if repo_token:
             branch.repository.dont_leave_lock_in_place()
         branch.dont_leave_lock_in_place()
         branch.unlock()
-        return SuccessfulSmartServerResponse((b'ok',))
+        return SuccessfulSmartServerResponse((b"ok",))
 
 
 class SmartServerBranchRequestGetPhysicalLockStatus(SmartServerBranchRequest):
@@ -430,9 +426,9 @@ class SmartServerBranchRequestGetPhysicalLockStatus(SmartServerBranchRequest):
 
     def do_with_branch(self, branch):
         if branch.get_physical_lock_status():
-            return SuccessfulSmartServerResponse((b'yes',))
+            return SuccessfulSmartServerResponse((b"yes",))
         else:
-            return SuccessfulSmartServerResponse((b'no',))
+            return SuccessfulSmartServerResponse((b"no",))
 
 
 class SmartServerBranchRequestGetAllReferenceInfo(SmartServerBranchRequest):
@@ -443,7 +439,14 @@ class SmartServerBranchRequestGetAllReferenceInfo(SmartServerBranchRequest):
 
     def do_with_branch(self, branch):
         all_reference_info = branch._get_all_reference_info()
-        content = bencode.bencode([
-            (key, value[0].encode('utf-8'), value[1].encode('utf-8') if value[1] else b'')
-            for (key, value) in all_reference_info.items()])
-        return SuccessfulSmartServerResponse((b'ok', ), content)
+        content = bencode.bencode(
+            [
+                (
+                    key,
+                    value[0].encode("utf-8"),
+                    value[1].encode("utf-8") if value[1] else b"",
+                )
+                for (key, value) in all_reference_info.items()
+            ]
+        )
+        return SuccessfulSmartServerResponse((b"ok",), content)
