@@ -16,7 +16,7 @@
 
 # Author: Martin Pool <mbp@canonical.com>
 
-"""Weave - storage of related text file versions"""
+"""Weave - storage of related text file versions."""
 
 # XXX: If we do weaves this way, will a merge still behave the same
 # way if it's done in a different order?  That's a pretty desirable
@@ -72,24 +72,31 @@ import patiencediff
 
 from ..lazy_import import lazy_import
 
-lazy_import(globals(), """
+lazy_import(
+    globals(),
+    """
 from breezy import tsort
-""")
-from .. import errors, osutils
+""",
+)
+from .. import errors
 from .. import transport as _mod_transport
 from ..errors import RevisionAlreadyPresent, RevisionNotPresent
-from ..osutils import dirname, sha, sha_strings, split_lines
+from ..osutils import dirname, sha, sha_strings
 from ..revision import NULL_REVISION
 from ..trace import mutter
-from .versionedfile import (AbsentContentFactory, ContentFactory,
-                            ExistingContent, UnavailableRepresentation,
-                            VersionedFile, adapter_registry,
-                            sort_groupcompress)
+from .versionedfile import (
+    AbsentContentFactory,
+    ContentFactory,
+    ExistingContent,
+    UnavailableRepresentation,
+    VersionedFile,
+    adapter_registry,
+    sort_groupcompress,
+)
 from .weavefile import _read_weave_v5, write_weave_v5
 
 
 class WeaveError(errors.BzrError):
-
     _fmt = "Error in processing weave: %(msg)s"
 
     def __init__(self, msg=None):
@@ -98,18 +105,15 @@ class WeaveError(errors.BzrError):
 
 
 class WeaveRevisionAlreadyPresent(WeaveError):
-
     _fmt = "Revision {%(revision_id)s} already present in %(weave)s"
 
     def __init__(self, revision_id, weave):
-
         WeaveError.__init__(self)
         self.revision_id = revision_id
         self.weave = weave
 
 
 class WeaveRevisionNotPresent(WeaveError):
-
     _fmt = "Revision {%(revision_id)s} not present in %(weave)s"
 
     def __init__(self, revision_id, weave):
@@ -119,7 +123,6 @@ class WeaveRevisionNotPresent(WeaveError):
 
 
 class WeaveFormatError(WeaveError):
-
     _fmt = "Weave invariant violated: %(what)s"
 
     def __init__(self, what):
@@ -128,19 +131,18 @@ class WeaveFormatError(WeaveError):
 
 
 class WeaveParentMismatch(WeaveError):
-
     _fmt = "Parents are mismatched between two revisions. %(msg)s"
 
 
 class WeaveInvalidChecksum(WeaveError):
-
     _fmt = "Text did not match its checksum: %(msg)s"
 
 
 class WeaveTextDiffers(WeaveError):
-
-    _fmt = ("Weaves differ on text content. Revision:"
-            " {%(revision_id)s}, %(weave_a)s, %(weave_b)s")
+    _fmt = (
+        "Weaves differ on text content. Revision:"
+        " {%(revision_id)s}, %(weave_a)s, %(weave_b)s"
+    )
 
     def __init__(self, revision_id, weave_a, weave_b):
         WeaveError.__init__(self)
@@ -162,22 +164,22 @@ class WeaveContentFactory(ContentFactory):
         self.key = (version,)
         parents = weave.get_parent_map([version])[version]
         self.parents = tuple((parent,) for parent in parents)
-        self.storage_kind = 'fulltext'
+        self.storage_kind = "fulltext"
         self._weave = weave
 
     def get_bytes_as(self, storage_kind):
-        if storage_kind == 'fulltext':
+        if storage_kind == "fulltext":
             return self._weave.get_text(self.key[-1])
-        elif storage_kind in ('chunked', 'lines'):
+        elif storage_kind in ("chunked", "lines"):
             return self._weave.get_lines(self.key[-1])
         else:
-            raise UnavailableRepresentation(self.key, storage_kind, 'fulltext')
+            raise UnavailableRepresentation(self.key, storage_kind, "fulltext")
 
     def iter_bytes_as(self, storage_kind):
-        if storage_kind in ('chunked', 'lines'):
+        if storage_kind in ("chunked", "lines"):
             return iter(self._weave.get_lines(self.key[-1]))
         else:
-            raise UnavailableRepresentation(self.key, storage_kind, 'fulltext')
+            raise UnavailableRepresentation(self.key, storage_kind, "fulltext")
 
 
 class Weave(VersionedFile):
@@ -269,11 +271,25 @@ class Weave(VersionedFile):
         Set by read_weave.
     """
 
-    __slots__ = ['_weave', '_parents', '_sha1s', '_names', '_name_map',
-                 '_weave_name', '_matcher', '_allow_reserved']
+    __slots__ = [
+        "_allow_reserved",
+        "_matcher",
+        "_name_map",
+        "_names",
+        "_parents",
+        "_sha1s",
+        "_weave",
+        "_weave_name",
+    ]
 
-    def __init__(self, weave_name=None, access_mode='w', matcher=None,
-                 get_scope=None, allow_reserved=False):
+    def __init__(
+        self,
+        weave_name=None,
+        access_mode="w",
+        matcher=None,
+        get_scope=None,
+        allow_reserved=False,
+    ):
         """Create a weave.
 
         :param get_scope: A callable that returns an opaque object to be used
@@ -292,27 +308,30 @@ class Weave(VersionedFile):
         else:
             self._matcher = matcher
         if get_scope is None:
+
             def get_scope():
                 return None
+
         self._get_scope = get_scope
         self._scope = get_scope()
         self._access_mode = access_mode
         self._allow_reserved = allow_reserved
 
     def __repr__(self):
-        return "Weave(%r)" % self._weave_name
+        return "Weave({!r})".format(self._weave_name)
 
     def _check_write_ok(self):
         """Is the versioned file marked as 'finished' ? Raise if it is."""
         if self._get_scope() != self._scope:
             raise errors.OutSideTransaction()
-        if self._access_mode != 'w':
+        if self._access_mode != "w":
             raise errors.ReadOnlyObjectDirtiedError(self)
 
     def copy(self):
         """Return a deep copy of self.
 
-        The copy can be modified without affecting the original weave."""
+        The copy can be modified without affecting the original weave.
+        """
         other = Weave()
         other._weave = self._weave[:]
         other._parents = self._parents[:]
@@ -325,9 +344,11 @@ class Weave(VersionedFile):
     def __eq__(self, other):
         if not isinstance(other, Weave):
             return False
-        return self._parents == other._parents \
-            and self._weave == other._weave \
+        return (
+            self._parents == other._parents
+            and self._weave == other._weave
             and self._sha1s == other._sha1s
+        )
 
     def __ne__(self, other):
         return not self.__eq__(other)
@@ -341,8 +362,8 @@ class Weave(VersionedFile):
             self.check_not_reserved_id(name)
         try:
             return self._name_map[name]
-        except KeyError:
-            raise RevisionNotPresent(name, self._weave_name)
+        except KeyError as err:
+            raise RevisionNotPresent(name, self._weave_name) from err
 
     def versions(self):
         """See VersionedFile.versions."""
@@ -350,7 +371,7 @@ class Weave(VersionedFile):
 
     def has_version(self, version_id):
         """See VersionedFile.has_version."""
-        return (version_id in self._name_map)
+        return version_id in self._name_map
 
     __contains__ = has_version
 
@@ -368,12 +389,12 @@ class Weave(VersionedFile):
             valid until the iterator is advanced.
         """
         versions = [version[-1] for version in versions]
-        if ordering == 'topological':
+        if ordering == "topological":
             parents = self.get_parent_map(versions)
             new_versions = tsort.topo_sort(parents)
             new_versions.extend(set(versions).difference(set(parents)))
             versions = new_versions
-        elif ordering == 'groupcompress':
+        elif ordering == "groupcompress":
             parents = self.get_parent_map(versions)
             new_versions = sort_groupcompress(parents)
             new_versions.extend(set(versions).difference(set(parents)))
@@ -393,8 +414,8 @@ class Weave(VersionedFile):
             else:
                 try:
                     parents = tuple(
-                        map(self._idx_to_name,
-                            self._parents[self._lookup(version_id)]))
+                        map(self._idx_to_name, self._parents[self._lookup(version_id)])
+                    )
                 except RevisionNotPresent:
                     continue
             result[version_id] = parents
@@ -413,23 +434,21 @@ class Weave(VersionedFile):
         adapters = {}
         for record in stream:
             # Raise an error when a record is missing.
-            if record.storage_kind == 'absent':
+            if record.storage_kind == "absent":
                 raise RevisionNotPresent([record.key[0]], self)
             # adapt to non-tuple interface
             parents = [parent[0] for parent in record.parents]
-            if record.storage_kind in ('fulltext', 'chunked', 'lines'):
-                self.add_lines(
-                    record.key[0], parents,
-                    record.get_bytes_as('lines'))
+            if record.storage_kind in ("fulltext", "chunked", "lines"):
+                self.add_lines(record.key[0], parents, record.get_bytes_as("lines"))
             else:
-                adapter_key = record.storage_kind, 'lines'
+                adapter_key = record.storage_kind, "lines"
                 try:
                     adapter = adapters[adapter_key]
                 except KeyError:
                     adapter_factory = adapter_registry.get(adapter_key)
                     adapter = adapter_factory(self)
                     adapters[adapter_key] = adapter
-                lines = adapter.get_bytes(record, 'lines')
+                lines = adapter.get_bytes(record, "lines")
                 try:
                     self.add_lines(record.key[0], parents, lines)
                 except RevisionAlreadyPresent:
@@ -441,17 +460,25 @@ class Weave(VersionedFile):
         If it is, return the (old) index; otherwise raise an exception.
         """
         idx = self._lookup(name)
-        if sorted(self._parents[idx]) != sorted(parents) \
-                or sha1 != self._sha1s[idx]:
+        if sorted(self._parents[idx]) != sorted(parents) or sha1 != self._sha1s[idx]:
             raise RevisionAlreadyPresent(name, self._weave_name)
         return idx
 
-    def _add_lines(self, version_id, parents, lines, parent_texts,
-                   left_matching_blocks, nostore_sha, random_id,
-                   check_content):
+    def _add_lines(
+        self,
+        version_id,
+        parents,
+        lines,
+        parent_texts,
+        left_matching_blocks,
+        nostore_sha,
+        random_id,
+        check_content,
+    ):
         """See VersionedFile.add_lines."""
-        idx = self._add(version_id, lines, list(map(self._lookup, parents)),
-                        nostore_sha=nostore_sha)
+        idx = self._add(
+            version_id, lines, list(map(self._lookup, parents)), nostore_sha=nostore_sha
+        )
         return sha_strings(lines), sum(map(len, lines)), idx
 
     def _add(self, version_id, lines, parents, sha1=None, nostore_sha=None):
@@ -501,9 +528,9 @@ class Weave(VersionedFile):
             # even more specially, if we're adding an empty text we
             # need do nothing at all.
             if lines:
-                self._weave.append((b'{', new_version))
+                self._weave.append((b"{", new_version))
                 self._weave.extend(lines)
-                self._weave.append((b'}', None))
+                self._weave.append((b"}", None))
             return new_version
 
         if len(parents) == 1:
@@ -514,12 +541,10 @@ class Weave(VersionedFile):
 
         ancestors = self._inclusions(parents)
 
-        l = self._weave
-
         # basis a list of (origin, lineno, line)
         basis_lineno = []
         basis_lines = []
-        for origin, lineno, line in self._extract(ancestors):
+        for _origin, lineno, line in self._extract(ancestors):
             basis_lineno.append(lineno)
             basis_lines.append(line)
 
@@ -549,15 +574,15 @@ class Weave(VersionedFile):
             # i1,i2 are given in offsets within basis_lines; we need to map
             # them back to offsets within the entire weave print 'raw match',
             # tag, i1, i2, j1, j2
-            if tag == 'equal':
+            if tag == "equal":
                 continue
             i1 = basis_lineno[i1]
             i2 = basis_lineno[i2]
             # the deletion and insertion are handled separately.
             # first delete the region.
             if i1 != i2:
-                self._weave.insert(i1 + offset, (b'[', new_version))
-                self._weave.insert(i2 + offset + 1, (b']', new_version))
+                self._weave.insert(i1 + offset, (b"[", new_version))
+                self._weave.insert(i2 + offset + 1, (b"]", new_version))
                 offset += 2
 
             if j1 != j2:
@@ -565,9 +590,7 @@ class Weave(VersionedFile):
                 # i2; we want to insert after this region to make sure
                 # we don't destroy ourselves
                 i = i2 + offset
-                self._weave[i:i] = ([(b'{', new_version)] +
-                                    lines[j1:j2] +
-                                    [(b'}', None)])
+                self._weave[i:i] = [(b"{", new_version)] + lines[j1:j2] + [(b"}", None)]
                 offset += 2 + (j2 - j1)
         return new_version
 
@@ -590,12 +613,12 @@ class Weave(VersionedFile):
         return {self._idx_to_name(v) for v in i}
 
     def _check_versions(self, indexes):
-        """Check everything in the sequence of indexes is valid"""
+        """Check everything in the sequence of indexes is valid."""
         for i in indexes:
             try:
                 self._parents[i]
-            except IndexError:
-                raise IndexError("invalid version number %r" % i)
+            except IndexError as err:
+                raise IndexError("invalid version number {!r}".format(i)) from err
 
     def _compatible_parents(self, my_parents, other_parents):
         """During join check that other_parents are joinable with my_parents.
@@ -608,57 +631,58 @@ class Weave(VersionedFile):
     def annotate(self, version_id):
         """Return a list of (version-id, line) tuples for version_id.
 
-        The index indicates when the line originated in the weave."""
+        The index indicates when the line originated in the weave.
+        """
         incls = [self._lookup(version_id)]
-        return [(self._idx_to_name(origin), text) for origin, lineno, text in
-                self._extract(incls)]
+        return [
+            (self._idx_to_name(origin), text)
+            for origin, lineno, text in self._extract(incls)
+        ]
 
-    def iter_lines_added_or_present_in_versions(self, version_ids=None,
-                                                pb=None):
+    def iter_lines_added_or_present_in_versions(self, version_ids=None, pb=None):
         """See VersionedFile.iter_lines_added_or_present_in_versions()."""
         if version_ids is None:
             version_ids = self.versions()
         version_ids = set(version_ids)
-        for lineno, inserted, deletes, line in self._walk_internal(
-                version_ids):
+        for _lineno, inserted, _deletes, line in self._walk_internal(version_ids):
             if inserted not in version_ids:
                 continue
-            if not line.endswith(b'\n'):
-                yield line + b'\n', inserted
+            if not line.endswith(b"\n"):
+                yield line + b"\n", inserted
             else:
                 yield line, inserted
 
     def _walk_internal(self, version_ids=None):
         """Helper method for weave actions."""
-
         istack = []
         dset = set()
 
-        lineno = 0         # line of weave, 0-based
+        lineno = 0  # line of weave, 0-based
 
-        for l in self._weave:
-            if l.__class__ == tuple:
+        for lineno, l in enumerate(self._weave):
+            if isinstance(l, tuple):
                 c, v = l
-                if c == b'{':
+                if c == b"{":
                     istack.append(self._names[v])
-                elif c == b'}':
+                elif c == b"}":
                     istack.pop()
-                elif c == b'[':
+                elif c == b"[":
                     dset.add(self._names[v])
-                elif c == b']':
+                elif c == b"]":
                     dset.remove(self._names[v])
                 else:
-                    raise WeaveFormatError('unexpected instruction %r' % v)
+                    raise WeaveFormatError("unexpected instruction {!r}".format(v))
             else:
                 yield lineno, istack[-1], frozenset(dset), l
-            lineno += 1
 
         if istack:
-            raise WeaveFormatError("unclosed insertion blocks "
-                                   "at end of weave: %s" % istack)
+            raise WeaveFormatError(
+                "unclosed insertion blocks at end of weave: {}".format(istack)
+            )
         if dset:
             raise WeaveFormatError(
-                "unclosed deletion blocks at end of weave: %s" % dset)
+                "unclosed deletion blocks at end of weave: {}".format(dset)
+            )
 
     def plan_merge(self, ver_a, ver_b):
         """Return pseudo-annotation indicating how the two versions merge.
@@ -672,38 +696,37 @@ class Weave(VersionedFile):
         inc_b = self.get_ancestry([ver_b])
         inc_c = inc_a & inc_b
 
-        for lineno, insert, deleteset, line in self._walk_internal(
-                [ver_a, ver_b]):
+        for _lineno, insert, deleteset, line in self._walk_internal([ver_a, ver_b]):
             if deleteset & inc_c:
                 # killed in parent; can't be in either a or b
                 # not relevant to our work
-                yield 'killed-base', line
+                yield "killed-base", line
             elif insert in inc_c:
                 # was inserted in base
                 killed_a = bool(deleteset & inc_a)
                 killed_b = bool(deleteset & inc_b)
                 if killed_a and killed_b:
-                    yield 'killed-both', line
+                    yield "killed-both", line
                 elif killed_a:
-                    yield 'killed-a', line
+                    yield "killed-a", line
                 elif killed_b:
-                    yield 'killed-b', line
+                    yield "killed-b", line
                 else:
-                    yield 'unchanged', line
+                    yield "unchanged", line
             elif insert in inc_a:
                 if deleteset & inc_a:
-                    yield 'ghost-a', line
+                    yield "ghost-a", line
                 else:
                     # new in A; not in B
-                    yield 'new-a', line
+                    yield "new-a", line
             elif insert in inc_b:
                 if deleteset & inc_b:
-                    yield 'ghost-b', line
+                    yield "ghost-b", line
                 else:
-                    yield 'new-b', line
+                    yield "new-b", line
             else:
                 # not in either revision
-                yield 'irrelevant', line
+                yield "irrelevant", line
 
     def _extract(self, versions):
         """Yield annotation of lines in included set.
@@ -724,7 +747,7 @@ class Weave(VersionedFile):
         iset = set()
         dset = set()
 
-        lineno = 0         # line of weave, 0-based
+        lineno = 0  # line of weave, 0-based
 
         isactive = None
 
@@ -754,36 +777,36 @@ class Weave(VersionedFile):
         # 'in' test could dominate, so I'm leaving this change in place - when
         # its fast enough to consider profiling big datasets we can review.
 
-        for l in self._weave:
-            if l.__class__ == tuple:
+        for lineno, l in enumerate(self._weave):
+            if isinstance(l, tuple):
                 c, v = l
                 isactive = None
-                if c == b'{':
+                if c == b"{":
                     istack.append(v)
                     iset.add(v)
-                elif c == b'}':
+                elif c == b"}":
                     iset.remove(istack.pop())
-                elif c == b'[':
+                elif c == b"[":
                     if v in included:
                         dset.add(v)
-                elif c == b']':
+                elif c == b"]":
                     if v in included:
                         dset.remove(v)
                 else:
                     raise AssertionError()
             else:
                 if isactive is None:
-                    isactive = (not dset) and istack and (
-                        istack[-1] in included)
+                    isactive = (not dset) and istack and (istack[-1] in included)
                 if isactive:
                     result.append((istack[-1], lineno, l))
-            lineno += 1
         if istack:
-            raise WeaveFormatError("unclosed insertion blocks "
-                                   "at end of weave: %s" % istack)
+            raise WeaveFormatError(
+                "unclosed insertion blocks at end of weave: {}".format(istack)
+            )
         if dset:
             raise WeaveFormatError(
-                "unclosed deletion blocks at end of weave: %s" % dset)
+                "unclosed deletion blocks at end of weave: {}".format(dset)
+            )
         return result
 
     def _maybe_lookup(self, name_or_index):
@@ -801,15 +824,15 @@ class Weave(VersionedFile):
     def get_lines(self, version_id):
         """See VersionedFile.get_lines()."""
         int_index = self._maybe_lookup(version_id)
-        result = [line for (origin, lineno, line)
-                  in self._extract([int_index])]
+        result = [line for (origin, lineno, line) in self._extract([int_index])]
         expected_sha1 = self._sha1s[int_index]
         measured_sha1 = sha_strings(result)
         if measured_sha1 != expected_sha1:
             raise WeaveInvalidChecksum(
-                'file %s, revision %s, expected: %s, measured %s'
-                % (self._weave_name, version_id,
-                   expected_sha1, measured_sha1))
+                "file {}, revision {}, expected: {}, measured {}".format(
+                    self._weave_name, version_id, expected_sha1, measured_sha1
+                )
+            )
         return result
 
     def get_sha1s(self, version_ids):
@@ -835,8 +858,8 @@ class Weave(VersionedFile):
                 inclusions.sort()
                 if inclusions[-1] >= version:
                     raise WeaveFormatError(
-                        "invalid included version %d for index %d"
-                        % (inclusions[-1], version))
+                        f"invalid included version {inclusions[-1]} for index {version}"
+                    )
 
         # try extracting all versions; parallel extraction is used
         nv = self.num_versions()
@@ -855,16 +878,16 @@ class Weave(VersionedFile):
 
             if new_inc != self.get_ancestry(name):
                 raise AssertionError(
-                    'failed %s != %s'
-                    % (new_inc, self.get_ancestry(name)))
+                    "failed {} != {}".format(new_inc, self.get_ancestry(name))
+                )
             inclusions[name] = new_inc
 
         nlines = len(self._weave)
 
-        update_text = 'checking weave'
+        update_text = "checking weave"
         if self._weave_name:
             short_name = os.path.basename(self._weave_name)
-            update_text = 'checking {}'.format(short_name)
+            update_text = "checking {}".format(short_name)
             update_text = update_text[:25]
 
         for lineno, insert, deleteset, line in self._walk_internal():
@@ -875,8 +898,7 @@ class Weave(VersionedFile):
                 # The active inclusion must be an ancestor,
                 # and no ancestors must have deleted this line,
                 # because we don't support resurrection.
-                if ((insert in name_inclusions) and
-                        not (deleteset & name_inclusions)):
+                if (insert in name_inclusions) and not (deleteset & name_inclusions):
                     sha1s[name].update(line)
 
         for i in range(nv):
@@ -885,9 +907,10 @@ class Weave(VersionedFile):
             expected = self._sha1s[i]
             if hd != expected:
                 raise WeaveInvalidChecksum(
-                    "mismatched sha1 for version %s: "
-                    "got %s, expected %s"
-                    % (version, hd, expected))
+                    "mismatched sha1 for version {}: got {}, expected {}".format(
+                        version, hd, expected
+                    )
+                )
 
         # TODO: check insertions are properly nested, that there are
         # no lines outside of insertion blocks, that deletions are
@@ -900,8 +923,11 @@ class Weave(VersionedFile):
             parent_name = other._names[parent_idx]
             if parent_name not in self._name_map:
                 # should not be possible
-                raise WeaveError("missing parent {%s} of {%s} in %r"
-                                 % (parent_name, other._name_map[other_idx], self))
+                raise WeaveError(
+                    "missing parent {{{}}} of {{{}}} in {!r}".format(
+                        parent_name, other._name_map[other_idx], self
+                    )
+                )
             new_parents.append(self._name_map[parent_name])
         return new_parents
 
@@ -916,7 +942,8 @@ class Weave(VersionedFile):
 
         If present & correct return True;
         if not present in self return False;
-        if inconsistent raise error."""
+        if inconsistent raise error.
+        """
         this_idx = self._name_map.get(name, -1)
         if this_idx != -1:
             if self._sha1s[this_idx] != other._sha1s[other_idx]:
@@ -927,10 +954,12 @@ class Weave(VersionedFile):
             n2 = {other._names[i] for i in other_parents}
             if not self._compatible_parents(n1, n2):
                 raise WeaveParentMismatch(
-                    "inconsistent parents "
-                    "for version {%s}: %s vs %s" % (name, n1, n2))
+                    "inconsistent parents for version {{{}}}: {} vs {}".format(
+                        name, n1, n2
+                    )
+                )
             else:
-                return True         # ok!
+                return True  # ok!
         else:
             return False
 
@@ -945,25 +974,31 @@ class Weave(VersionedFile):
         self._copy_weave_content(new_weave)
 
     def _copy_weave_content(self, otherweave):
-        """adsorb the content from otherweave."""
+        """Adsorb the content from otherweave."""
         for attr in self.__slots__:
-            if attr != '_weave_name':
+            if attr != "_weave_name":
                 setattr(self, attr, copy(getattr(otherweave, attr)))
 
 
 class WeaveFile(Weave):
     """A WeaveFile represents a Weave on disk and writes on change."""
 
-    WEAVE_SUFFIX = '.weave'
+    WEAVE_SUFFIX = ".weave"
 
-    def __init__(self, name, transport, filemode=None, create=False,
-                 access_mode='w', get_scope=None):
+    def __init__(
+        self,
+        name,
+        transport,
+        filemode=None,
+        create=False,
+        access_mode="w",
+        get_scope=None,
+    ):
         """Create a WeaveFile.
 
         :param create: If not True, only open an existing knit.
         """
-        super().__init__(name, access_mode, get_scope=get_scope,
-                                        allow_reserved=False)
+        super().__init__(name, access_mode, get_scope=get_scope, allow_reserved=False)
         self._transport = transport
         self._filemode = filemode
         try:
@@ -975,14 +1010,29 @@ class WeaveFile(Weave):
             # new file, save it
             self._save()
 
-    def _add_lines(self, version_id, parents, lines, parent_texts,
-                   left_matching_blocks, nostore_sha, random_id,
-                   check_content):
+    def _add_lines(
+        self,
+        version_id,
+        parents,
+        lines,
+        parent_texts,
+        left_matching_blocks,
+        nostore_sha,
+        random_id,
+        check_content,
+    ):
         """Add a version and save the weave."""
         self.check_not_reserved_id(version_id)
         result = super()._add_lines(
-            version_id, parents, lines, parent_texts, left_matching_blocks,
-            nostore_sha, random_id, check_content)
+            version_id,
+            parents,
+            lines,
+            parent_texts,
+            left_matching_blocks,
+            nostore_sha,
+            random_id,
+            check_content,
+        )
         self._save()
         return result
 
@@ -1042,7 +1092,7 @@ def _reweave(wa, wb, pb=None, msg=None):
     mutter("order to reweave: %r", order)
 
     if pb and not msg:
-        msg = 'reweave'
+        msg = "reweave"
 
     for idx, name in enumerate(order):
         if pb:
@@ -1052,12 +1102,16 @@ def _reweave(wa, wb, pb=None, msg=None):
             if name in wb._name_map:
                 lines_b = wb.get_lines(name)
                 if lines != lines_b:
-                    mutter('Weaves differ on content. rev_id {%s}', name)
-                    mutter('weaves: %s, %s', wa._weave_name, wb._weave_name)
+                    mutter("Weaves differ on content. rev_id {%s}", name)
+                    mutter("weaves: %s, %s", wa._weave_name, wb._weave_name)
                     import difflib
-                    lines = list(difflib.unified_diff(lines, lines_b,
-                                                      wa._weave_name, wb._weave_name))
-                    mutter('lines:\n%s', ''.join(lines))
+
+                    lines = list(
+                        difflib.unified_diff(
+                            lines, lines_b, wa._weave_name, wb._weave_name
+                        )
+                    )
+                    mutter("lines:\n%s", "".join(lines))
                     raise WeaveTextDiffers(name, wa, wb)
         else:
             lines = wb.get_lines(name)
@@ -1068,7 +1122,8 @@ def _reweave(wa, wb, pb=None, msg=None):
 def _reweave_parent_graphs(wa, wb):
     """Return combined parent ancestry for two weaves.
 
-    Returned as a list of (version_name, set(parent_names))"""
+    Returned as a list of (version_name, set(parent_names))
+    """
     combined = {}
     for weave in [wa, wb]:
         for idx, name in enumerate(weave._names):
