@@ -22,15 +22,13 @@ from .trace import note
 
 
 class GhostFetcher:
-
     @classmethod
     def from_cmdline(cls, other):
-        this_branch = Branch.open_containing('.')[0]
+        this_branch = Branch.open_containing(".")[0]
         if other is None:
             other = this_branch.get_parent()
             if other is None:
-                raise CommandError('No branch specified and no location'
-                                   ' saved.')
+                raise CommandError("No branch specified and no location saved.")
             else:
                 note("Using saved location %s.", other)
         other_branch = Branch.open_containing(other)[0]
