@@ -19,11 +19,10 @@
 
 import posixpath
 import stat
-from typing import Dict, Iterable, Iterator, List
+from collections.abc import Iterable, Iterator
 
 from dulwich.object_store import BaseObjectStore
-from dulwich.objects import (ZERO_SHA, Blob, Commit, ObjectID, ShaFile, Tree,
-                             sha_to_hex)
+from dulwich.objects import ZERO_SHA, Blob, Commit, ObjectID, ShaFile, Tree, sha_to_hex
 from dulwich.pack import Pack, PackData, pack_objects_to_data
 
 from .. import errors, lru_cache, osutils, trace, ui
@@ -32,11 +31,17 @@ from ..lock import LogicalLockResult
 from ..revision import NULL_REVISION
 from ..tree import InterTree
 from .cache import from_repository as cache_from_repository
-from .mapping import (default_mapping, encode_git_path, entry_mode,
-                      extract_unusual_modes, mapping_registry, symlink_to_blob)
+from .mapping import (
+    default_mapping,
+    encode_git_path,
+    entry_mode,
+    extract_unusual_modes,
+    mapping_registry,
+    symlink_to_blob,
+)
 from .unpeel_map import UnpeelMap
 
-BANNED_FILENAMES = ['.git']
+BANNED_FILENAMES = [".git"]
 
 
 def get_object_store(repo, mapping=None):
@@ -53,15 +58,17 @@ MAX_TREE_CACHE_SIZE = 50 * 1024 * 1024
 
 
 class LRUTreeCache:
-
     def __init__(self, repository):
         def approx_tree_size(tree):
             # Very rough estimate, 250 per inventory entry
             return len(tree.root_inventory) * 250
+
         self.repository = repository
         self._cache = lru_cache.LRUSizeCache(
-            max_size=MAX_TREE_CACHE_SIZE, after_cleanup_size=None,
-            compute_size=approx_tree_size)
+            max_size=MAX_TREE_CACHE_SIZE,
+            after_cleanup_size=None,
+            compute_size=approx_tree_size,
+        )
 
     def revision_tree(self, revid):
         try:
@@ -83,7 +90,9 @@ class LRUTreeCache:
                 if tree.get_revision_id() != revid:
                     raise AssertionError(
                         "revision id did not match: {} != {}".format(
-                            tree.get_revision_id(), revid))
+                            tree.get_revision_id(), revid
+                        )
+                    )
                 trees[revid] = tree
         for tree in self.repository.revision_trees(todo):
             trees[tree.get_revision_id()] = tree
@@ -130,20 +139,22 @@ def _check_expected_sha(expected_sha, object):
     if expected_sha is None:
         return
     if len(expected_sha) == 40:
-        if expected_sha != object.sha().hexdigest().encode('ascii'):
-            raise AssertionError("Invalid sha for {!r}: {}".format(object,
-                                                             expected_sha))
+        if expected_sha != object.sha().hexdigest().encode("ascii"):
+            raise AssertionError(
+                "Invalid sha for {!r}: {}".format(object, expected_sha)
+            )
     elif len(expected_sha) == 20:
         if expected_sha != object.sha().digest():
-            raise AssertionError("Invalid sha for {!r}: {}".format(
-                object, sha_to_hex(expected_sha)))
+            raise AssertionError(
+                "Invalid sha for {!r}: {}".format(object, sha_to_hex(expected_sha))
+            )
     else:
-        raise AssertionError("Unknown length %d for %r" % (len(expected_sha),
-                                                           expected_sha))
+        raise AssertionError(f"Unknown length {len(expected_sha)} for {expected_sha!r}")
 
 
-def directory_to_tree(path, children, lookup_ie_sha1, unusual_modes,
-                      empty_file_name, allow_empty=False):
+def directory_to_tree(
+    path, children, lookup_ie_sha1, unusual_modes, empty_file_name, allow_empty=False
+):
     """Create a Git Tree object from a Bazaar directory.
 
     :param path: directory path
@@ -174,8 +185,9 @@ def directory_to_tree(path, children, lookup_ie_sha1, unusual_modes,
     return tree
 
 
-def _tree_to_objects(tree, parent_trees, idmap, unusual_modes,
-                     dummy_file_name=None, add_cache_entry=None):
+def _tree_to_objects(
+    tree, parent_trees, idmap, unusual_modes, dummy_file_name=None, add_cache_entry=None
+):
     """Iterate over the objects that were introduced in a revision.
 
     :param idmap: id map
@@ -202,15 +214,11 @@ def _tree_to_objects(tree, parent_trees, idmap, unusual_modes,
             if ppath is not None:
                 pkind = ptree.kind(ppath)
                 if kind == "file":
-                    if (pkind == "file" and
-                            ptree.get_file_sha1(ppath) == other):
-                        return (
-                            ptree.path2id(ppath), ptree.get_file_revision(ppath))
+                    if pkind == "file" and ptree.get_file_sha1(ppath) == other:
+                        return (ptree.path2id(ppath), ptree.get_file_revision(ppath))
                 if kind == "symlink":
-                    if (pkind == "symlink" and
-                            ptree.get_symlink_target(ppath) == other):
-                        return (
-                            ptree.path2id(ppath), ptree.get_file_revision(ppath))
+                    if pkind == "symlink" and ptree.get_symlink_target(ppath) == other:
+                        return (ptree.path2id(ppath), ptree.get_file_revision(ppath))
         raise KeyError
 
     # Find all the changed blobs
@@ -222,15 +230,15 @@ def _tree_to_objects(tree, parent_trees, idmap, unusual_modes,
             blob_id = None
             try:
                 (pfile_id, prevision) = find_unchanged_parent_ie(
-                    change.path[1], change.kind[1], sha1, other_parent_trees)
+                    change.path[1], change.kind[1], sha1, other_parent_trees
+                )
             except KeyError:
                 pass
             else:
                 # It existed in one of the parents, with the same contents.
                 # So no need to yield any new git objects.
                 try:
-                    blob_id = idmap.lookup_blob_id(
-                        pfile_id, prevision)
+                    blob_id = idmap.lookup_blob_id(pfile_id, prevision)
                 except KeyError:
                     if not change.changed_content:
                         # no-change merge ?
@@ -245,24 +253,33 @@ def _tree_to_objects(tree, parent_trees, idmap, unusual_modes,
                 if add_cache_entry is not None:
                     add_cache_entry(
                         ("blob", blob_id),
-                        (change.file_id, tree.get_file_revision(change.path[1])), change.path[1])
+                        (change.file_id, tree.get_file_revision(change.path[1])),
+                        change.path[1],
+                    )
         elif change.kind[1] == "symlink":
             target = tree.get_symlink_target(change.path[1])
             blob = symlink_to_blob(target)
             shamap[change.path[1]] = blob.id
             if add_cache_entry is not None:
                 add_cache_entry(
-                    blob, (change.file_id, tree.get_file_revision(change.path[1])), change.path[1])
+                    blob,
+                    (change.file_id, tree.get_file_revision(change.path[1])),
+                    change.path[1],
+                )
             try:
                 find_unchanged_parent_ie(
-                    change.path[1], change.kind[1], target, other_parent_trees)
+                    change.path[1], change.kind[1], target, other_parent_trees
+                )
             except KeyError:
                 if change.changed_content:
-                    yield (change.path[1], blob,
-                           (change.file_id, tree.get_file_revision(change.path[1])))
+                    yield (
+                        change.path[1],
+                        blob,
+                        (change.file_id, tree.get_file_revision(change.path[1])),
+                    )
         elif change.kind[1] is None:
             shamap[change.path[1]] = None
-        elif change.kind[1] != 'directory':
+        elif change.kind[1] != "directory":
             raise AssertionError(change.kind[1])
         for p in change.path:
             if p is None:
@@ -271,7 +288,8 @@ def _tree_to_objects(tree, parent_trees, idmap, unusual_modes,
 
     # Fetch contents of the blobs that were changed
     for (path, file_id), chunks in tree.iter_files_bytes(
-            [(path, (path, file_id)) for (path, file_id) in new_blobs]):
+        [(path, (path, file_id)) for (path, file_id) in new_blobs]
+    ):
         obj = Blob()
         obj.chunked = list(chunks)
         if add_cache_entry is not None:
@@ -289,7 +307,7 @@ def _tree_to_objects(tree, parent_trees, idmap, unusual_modes,
             dirty_dirs.add(parent)
 
     if dirty_dirs:
-        dirty_dirs.add('')
+        dirty_dirs.add("")
 
     def ie_to_hexsha(path, ie):
         try:
@@ -321,8 +339,13 @@ def _tree_to_objects(tree, parent_trees, idmap, unusual_modes,
             # Not all cache backends store the tree information,
             # calculate again from scratch
             ret = directory_to_tree(
-                path, ie.children.values(), ie_to_hexsha, unusual_modes,
-                dummy_file_name, ie.parent_id is None)
+                path,
+                ie.children.values(),
+                ie_to_hexsha,
+                unusual_modes,
+                dummy_file_name,
+                ie.parent_id is None,
+            )
             if ret is None:
                 return ret
             return ret.id
@@ -333,12 +356,17 @@ def _tree_to_objects(tree, parent_trees, idmap, unusual_modes,
         if not tree.has_filename(path):
             continue
 
-        if tree.kind(path) != 'directory':
+        if tree.kind(path) != "directory":
             continue
 
         obj = directory_to_tree(
-            path, tree.iter_child_entries(path), ie_to_hexsha, unusual_modes,
-            dummy_file_name, path == '')
+            path,
+            tree.iter_child_entries(path),
+            ie_to_hexsha,
+            unusual_modes,
+            dummy_file_name,
+            path == "",
+        )
 
         if obj is not None:
             file_id = tree.path2id(path)
@@ -375,8 +403,7 @@ class BazaarObjectStore(BaseObjectStore):
             raise errors.LockNotHeld(self)
         if self._map_updated:
             return
-        if (stop_revision is not None and
-                not self._missing_revisions([stop_revision])):
+        if stop_revision is not None and not self._missing_revisions([stop_revision]):
             return
         graph = self.repository.get_graph()
         if stop_revision is None:
@@ -402,9 +429,8 @@ class BazaarObjectStore(BaseObjectStore):
         self.start_write_group()
         try:
             with ui.ui_factory.nested_progress_bar() as pb:
-                for i, revid in enumerate(graph.iter_topo_order(
-                        missing_revids)):
-                    trace.mutter('processing %r', revid)
+                for i, revid in enumerate(graph.iter_topo_order(missing_revids)):
+                    trace.mutter("processing %r", revid)
                     pb.update("updating git map", i, len(missing_revids))
                     self._update_sha_map_revision(revid)
             if stop_revision is None:
@@ -428,13 +454,16 @@ class BazaarObjectStore(BaseObjectStore):
         :param verifiers: Verifiers for the commits
         :return: Commit object
         """
+
         def parent_lookup(revid):
             try:
                 return self._lookup_revision_sha1(revid)
             except errors.NoSuchRevision:
                 return None
-        return self.mapping.export_commit(rev, tree_sha, parent_lookup,
-                                          lossy, verifiers)
+
+        return self.mapping.export_commit(
+            rev, tree_sha, parent_lookup, lossy, verifiers
+        )
 
     def _revision_to_objects(self, rev, tree, lossy, add_cache_entry=None):
         """Convert a revision to a set of git objects.
@@ -446,11 +475,17 @@ class BazaarObjectStore(BaseObjectStore):
         unusual_modes = extract_unusual_modes(rev)
         present_parents = self.repository.has_revisions(rev.parent_ids)
         parent_trees = self.tree_cache.revision_trees(
-            [p for p in rev.parent_ids if p in present_parents])
+            [p for p in rev.parent_ids if p in present_parents]
+        )
         root_tree = None
         for path, obj, bzr_key_data in _tree_to_objects(
-                tree, parent_trees, self._cache.idmap, unusual_modes,
-                self.mapping.BZR_DUMMY_FILE, add_cache_entry):
+            tree,
+            parent_trees,
+            self._cache.idmap,
+            unusual_modes,
+            self.mapping.BZR_DUMMY_FILE,
+            add_cache_entry,
+        ):
             if path == "":
                 root_tree = obj
                 root_key_data = bzr_key_data
@@ -464,7 +499,7 @@ class BazaarObjectStore(BaseObjectStore):
             else:
                 base_sha1 = self._lookup_revision_sha1(rev.parent_ids[0])
                 root_tree = self[self[base_sha1].tree]
-            root_key_data = (tree.path2id(''), tree.get_revision_id())
+            root_key_data = (tree.path2id(""), tree.get_revision_id())
         if add_cache_entry is not None:
             add_cache_entry(root_tree, root_key_data, "")
         yield "", root_tree
@@ -473,11 +508,11 @@ class BazaarObjectStore(BaseObjectStore):
             verifiers = {"testament3-sha1": testament3.as_sha1()}
         else:
             verifiers = {}
-        commit_obj = self._reconstruct_commit(rev, root_tree.id,
-                                              lossy=lossy, verifiers=verifiers)
+        commit_obj = self._reconstruct_commit(
+            rev, root_tree.id, lossy=lossy, verifiers=verifiers
+        )
         try:
-            foreign_revid, mapping = mapping_registry.parse_revision_id(
-                rev.revision_id)
+            foreign_revid, mapping = mapping_registry.parse_revision_id(rev.revision_id)
         except errors.InvalidRevisionId:
             pass
         else:
@@ -495,15 +530,25 @@ class BazaarObjectStore(BaseObjectStore):
         tree = self.tree_cache.revision_tree(rev.revision_id)
         updater = self._get_updater(rev)
         # FIXME JRV 2011-12-15: Shouldn't we try both values for lossy ?
-        for path, obj in self._revision_to_objects(
-                rev, tree, lossy=(not self.mapping.roundtripping),
-                add_cache_entry=updater.add_object):
+        for _path, obj in self._revision_to_objects(
+            rev,
+            tree,
+            lossy=(not self.mapping.roundtripping),
+            add_cache_entry=updater.add_object,
+        ):
             if isinstance(obj, Commit):
                 commit_obj = obj
         commit_obj = updater.finish()
         return commit_obj.id
 
-    def iter_unpacked_subset(self, shas, *, include_comp=False, allow_missing: bool = False, convert_ofs_delta: bool = True) -> Iterator[ShaFile]:
+    def iter_unpacked_subset(
+        self,
+        shas,
+        *,
+        include_comp=False,
+        allow_missing: bool = False,
+        convert_ofs_delta: bool = True,
+    ) -> Iterator[ShaFile]:
         # We don't store unpacked objects, so...
         if not allow_missing and shas:
             raise KeyError(shas.pop())
@@ -515,8 +560,7 @@ class BazaarObjectStore(BaseObjectStore):
         :param fileid: File id of the text
         :param revision: Revision of the text
         """
-        stream = self.repository.iter_files_bytes(
-            (key[0], key[1], key) for key in keys)
+        stream = self.repository.iter_files_bytes((key[0], key[1], key) for key in keys)
         for (file_id, revision, expected_sha), chunks in stream:
             blob = Blob()
             blob.chunked = list(chunks)
@@ -524,49 +568,57 @@ class BazaarObjectStore(BaseObjectStore):
                 # Perhaps it's a symlink ?
                 tree = self.tree_cache.revision_tree(revision)
                 path = tree.id2path(file_id)
-                if tree.kind(path) == 'symlink':
+                if tree.kind(path) == "symlink":
                     blob = symlink_to_blob(tree.get_symlink_target(path))
             _check_expected_sha(expected_sha, blob)
             yield blob
 
-    def _reconstruct_tree(self, fileid, revid, bzr_tree, unusual_modes,
-                          expected_sha=None):
+    def _reconstruct_tree(
+        self, fileid, revid, bzr_tree, unusual_modes, expected_sha=None
+    ):
         """Return a Git Tree object from a file id and a revision stored in bzr.
 
         :param fileid: fileid in the tree.
         :param revision: Revision of the tree.
         """
+
         def get_ie_sha1(path, entry):
             if entry.kind == "directory":
                 try:
-                    return self._cache.idmap.lookup_tree_id(entry.file_id,
-                                                            revid)
+                    return self._cache.idmap.lookup_tree_id(entry.file_id, revid)
                 except (NotImplementedError, KeyError):
                     obj = self._reconstruct_tree(
-                        entry.file_id, revid, bzr_tree, unusual_modes)
+                        entry.file_id, revid, bzr_tree, unusual_modes
+                    )
                     if obj is None:
                         return None
                     else:
                         return obj.id
             elif entry.kind in ("file", "symlink"):
                 try:
-                    return self._cache.idmap.lookup_blob_id(entry.file_id,
-                                                            entry.revision)
+                    return self._cache.idmap.lookup_blob_id(
+                        entry.file_id, entry.revision
+                    )
                 except KeyError:
                     # no-change merge?
-                    return next(self._reconstruct_blobs(
-                        [(entry.file_id, entry.revision, None)])).id
-            elif entry.kind == 'tree-reference':
+                    return next(
+                        self._reconstruct_blobs([(entry.file_id, entry.revision, None)])
+                    ).id
+            elif entry.kind == "tree-reference":
                 # FIXME: Make sure the file id is the root id
                 return self._lookup_revision_sha1(entry.reference_revision)
             else:
-                raise AssertionError("unknown entry kind '%s'" % entry.kind)
+                raise AssertionError("unknown entry kind '{}'".format(entry.kind))
+
         path = bzr_tree.id2path(fileid)
         tree = directory_to_tree(
             path,
             bzr_tree.iter_child_entries(path),
-            get_ie_sha1, unusual_modes, self.mapping.BZR_DUMMY_FILE,
-            bzr_tree.path2id('') == fileid)
+            get_ie_sha1,
+            unusual_modes,
+            self.mapping.BZR_DUMMY_FILE,
+            bzr_tree.path2id("") == fileid,
+        )
         if tree is not None:
             _check_expected_sha(expected_sha, tree)
         return tree
@@ -605,7 +657,7 @@ class BazaarObjectStore(BaseObjectStore):
     def __contains__(self, sha):
         # See if sha is in map
         try:
-            for (type, type_data) in self.lookup_git_sha(sha):
+            for type, type_data in self.lookup_git_sha(sha):
                 if type == "commit":
                     if self.repository.has_revision(type_data[0]):
                         return True
@@ -616,34 +668,34 @@ class BazaarObjectStore(BaseObjectStore):
                     if self.repository.has_revision(type_data[1]):
                         return True
                 else:
-                    raise AssertionError("Unknown object type '%s'" % type)
+                    raise AssertionError("Unknown object type '{}'".format(type))
             else:
                 return False
         except KeyError:
             return False
 
     def lock_read(self):
-        self._locked = 'r'
+        self._locked = "r"
         self._map_updated = False
         self.repository.lock_read()
         return LogicalLockResult(self.unlock)
 
     def lock_write(self):
-        self._locked = 'r'
+        self._locked = "r"
         self._map_updated = False
         self.repository.lock_write()
         return LogicalLockResult(self.unlock)
 
     def is_locked(self):
-        return (self._locked is not None)
+        return self._locked is not None
 
     def unlock(self):
         self._locked = None
         self._map_updated = False
         self.repository.unlock()
 
-    def lookup_git_shas(self, shas: Iterable[ObjectID]) -> Dict[ObjectID, List]:
-        ret: Dict[ObjectID, List] = {}
+    def lookup_git_shas(self, shas: Iterable[ObjectID]) -> dict[ObjectID, list]:
+        ret: dict[ObjectID, list] = {}
         for sha in shas:
             if sha == ZERO_SHA:
                 ret[sha] = [("commit", (NULL_REVISION, None, {}))]
@@ -665,7 +717,7 @@ class BazaarObjectStore(BaseObjectStore):
 
     def __getitem__(self, sha):
         with self.repository.lock_read():
-            for (kind, type_data) in self.lookup_git_sha(sha):
+            for kind, type_data in self.lookup_git_sha(sha):
                 # convert object to git object
                 if kind == "commit":
                     (revid, tree_sha, verifiers) = type_data
@@ -674,15 +726,24 @@ class BazaarObjectStore(BaseObjectStore):
                     except errors.NoSuchRevision:
                         if revid == NULL_REVISION:
                             raise AssertionError(
-                                "should not try to look up NULL_REVISION")
-                        trace.mutter('entry for %s %s in shamap: %r, but not '
-                                     'found in repository', kind, sha, type_data)
+                                "should not try to look up NULL_REVISION"
+                            )
+                        trace.mutter(
+                            "entry for %s %s in shamap: %r, but not "
+                            "found in repository",
+                            kind,
+                            sha,
+                            type_data,
+                        )
                         raise KeyError(sha)
                     # FIXME: the type data should say whether conversion was
                     # lossless
                     commit = self._reconstruct_commit(
-                        rev, tree_sha, lossy=(not self.mapping.roundtripping),
-                        verifiers=verifiers)
+                        rev,
+                        tree_sha,
+                        lossy=(not self.mapping.roundtripping),
+                        verifiers=verifiers,
+                    )
                     _check_expected_sha(sha, commit)
                     return commit
                 elif kind == "blob":
@@ -696,44 +757,65 @@ class BazaarObjectStore(BaseObjectStore):
                         rev = self.repository.get_revision(revid)
                     except errors.NoSuchRevision:
                         trace.mutter(
-                            'entry for %s %s in shamap: %r, but not found in '
-                            'repository', kind, sha, type_data)
+                            "entry for %s %s in shamap: %r, but not found in "
+                            "repository",
+                            kind,
+                            sha,
+                            type_data,
+                        )
                         raise KeyError(sha)
                     unusual_modes = extract_unusual_modes(rev)
                     try:
                         return self._reconstruct_tree(
-                            fileid, revid, tree, unusual_modes, expected_sha=sha)
+                            fileid, revid, tree, unusual_modes, expected_sha=sha
+                        )
                     except errors.NoSuchRevision:
                         raise KeyError(sha)
                 else:
-                    raise AssertionError("Unknown object type '%s'" % kind)
+                    raise AssertionError("Unknown object type '{}'".format(kind))
             else:
                 raise KeyError(sha)
 
-    def generate_lossy_pack_data(self, have, want, shallow=None,
-                                 progress=None,
-                                 get_tagged=None, ofs_delta=False):
-        object_ids = list(self.find_missing_objects(have, want, progress=progress,
-                                      shallow=shallow, get_tagged=get_tagged,
-                                      lossy=True))
-        return pack_objects_to_data([
-            (self[oid], path) for (oid, (type_num, path)) in object_ids])
+    def generate_lossy_pack_data(
+        self, have, want, shallow=None, progress=None, get_tagged=None, ofs_delta=False
+    ):
+        object_ids = list(
+            self.find_missing_objects(
+                have,
+                want,
+                progress=progress,
+                shallow=shallow,
+                get_tagged=get_tagged,
+                lossy=True,
+            )
+        )
+        return pack_objects_to_data(
+            [(self[oid], path) for (oid, (type_num, path)) in object_ids]
+        )
 
-    def find_missing_objects(self, have, want, shallow=None, progress=None,
-                             ofs_delta=False, get_tagged=None, lossy=False):
+    def find_missing_objects(
+        self,
+        have,
+        want,
+        shallow=None,
+        progress=None,
+        ofs_delta=False,
+        get_tagged=None,
+        lossy=False,
+    ):
         """Iterate over the contents of a pack file.
 
         :param have: List of SHA1s of objects that should not be sent
         :param want: List of SHA1s of objects that should be sent
         """
         processed = set()
-        ret: Dict[ObjectID, List] = self.lookup_git_shas(have + want)
+        ret: dict[ObjectID, List] = self.lookup_git_shas(have + want)
         for commit_sha in have:
             commit_sha = self.unpeel_map.peel_tag(commit_sha, commit_sha)
             try:
-                for (type, type_data) in ret[commit_sha]:
+                for type, type_data in ret[commit_sha]:
                     if type != "commit":
-                        raise AssertionError("Type was %s, not commit" % type)
+                        raise AssertionError("Type was {}, not commit".format(type))
                     processed.add(type_data[0])
             except KeyError:
                 trace.mutter("unable to find remote ref %s", commit_sha)
@@ -742,18 +824,18 @@ class BazaarObjectStore(BaseObjectStore):
             if commit_sha in have:
                 continue
             try:
-                for (type, type_data) in ret[commit_sha]:
+                for type, type_data in ret[commit_sha]:
                     if type != "commit":
-                        raise AssertionError("Type was %s, not commit" % type)
+                        raise AssertionError("Type was {}, not commit".format(type))
                     pending.add(type_data[0])
             except KeyError:
                 pass
         shallows = set()
         for commit_sha in shallow or set():
             try:
-                for (type, type_data) in ret[commit_sha]:
+                for type, type_data in ret[commit_sha]:
                     if type != "commit":
-                        raise AssertionError("Type was %s, not commit" % type)
+                        raise AssertionError("Type was {}, not commit".format(type))
                     shallows.add(type_data[0])
             except KeyError:
                 pass
@@ -770,8 +852,7 @@ class BazaarObjectStore(BaseObjectStore):
                     except errors.NoSuchRevision:
                         continue
                     tree = self.tree_cache.revision_tree(revid)
-                    for path, obj in self._revision_to_objects(
-                            rev, tree, lossy=lossy):
+                    for path, obj in self._revision_to_objects(rev, tree, lossy=lossy):
                         if obj.id not in seen:
                             yield (obj.id, (obj.type_num, path))
                             seen.add(obj.id)
@@ -779,11 +860,13 @@ class BazaarObjectStore(BaseObjectStore):
     def add_thin_pack(self):
         import os
         import tempfile
+
         fd, path = tempfile.mkstemp(suffix=".pack")
-        f = os.fdopen(fd, 'wb')
+        f = os.fdopen(fd, "wb")
 
         def commit():
             from .fetch import import_git_objects
+
             os.fsync(fd)
             f.close()
             if os.path.getsize(path) == 0:
@@ -795,14 +878,18 @@ class BazaarObjectStore(BaseObjectStore):
             with self.repository.lock_write():
                 self.repository.start_write_group()
                 try:
-                    import_git_objects(self.repository, self.mapping,
-                                       p.iterobjects(get_raw=self.get_raw),
-                                       self.object_store)
+                    import_git_objects(
+                        self.repository,
+                        self.mapping,
+                        p.iterobjects(get_raw=self.get_raw),
+                        self.object_store,
+                    )
                 except BaseException:
                     self.repository.abort_write_group()
                     raise
                 else:
                     self.repository.commit_write_group()
+
         return f, commit
 
     # The pack isn't kept around anyway, so no point
