@@ -15,14 +15,13 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-"""Test the GitDir class"""
+"""Test the GitDir class."""
 
 import os
 
 from dulwich.repo import Repo as GitRepo
 
 from ... import controldir, errors, urlutils
-from ...tests import TestSkipped
 from ...transport import get_transport
 from .. import dir, tests, workingtree
 
@@ -33,7 +32,7 @@ class TestGitDir(tests.TestCaseInTempDir):
 
         gd = controldir.ControlDir.open(".")
         self.assertEqual(
-            "%s,branch=master" % urlutils.local_path_to_url(os.path.abspath(".")),
+            "{},branch=master".format(urlutils.local_path_to_url(os.path.abspath("."))),
             gd.get_branch_reference(),
         )
 
@@ -61,7 +60,7 @@ class TestGitDir(tests.TestCaseInTempDir):
 
     def test_open_ref_parent(self):
         r = GitRepo.init(".")
-        cid = r.do_commit(message=b"message", ref=b"refs/heads/foo/bar")
+        r.do_commit(message=b"message", ref=b"refs/heads/foo/bar")
         gd = controldir.ControlDir.open(".")
         self.assertRaises(errors.NotBranchError, gd.open_branch, "foo")
 
