@@ -19,25 +19,13 @@
 See MutableTree for more details.
 """
 
-from __future__ import absolute_import
+from typing import Optional, Union
 
-from . import (
-    errors,
-    hooks,
-    osutils,
-    trace,
-    tree,
-    )
-
-from .sixish import (
-    text_type,
-    )
+from . import errors, hooks, trace, tree
 
 
 class BadReferenceTarget(errors.InternalBzrError):
-
-    _fmt = "Can't add reference to %(other_tree)s into %(tree)s." \
-           "%(reason)s"
+    _fmt = "Can't add reference to %(other_tree)s into %(tree)s.%(reason)s"
 
     def __init__(self, tree, other_tree, reason):
         self.tree = tree
@@ -65,7 +53,7 @@ class MutableTree(tree.Tree):
     """
 
     def __init__(self, *args, **kw):
-        super(MutableTree, self).__init__(*args, **kw)
+        super().__init__(*args, **kw)
         # Is this tree on a case-insensitive or case-preserving file-system?
         # Sub-classes may initialize to False if they detect they are being
         # used on media which doesn't differentiate the case of names.
@@ -83,7 +71,11 @@ class MutableTree(tree.Tree):
         """
         raise NotImplementedError(self.is_control_filename)
 
-    def add(self, files, ids=None, kinds=None):
+    def add(
+        self,
+        files: Union[str, list[str]],
+        kinds: Optional[Union[str, list[str]]] = None,
+    ):
         """Add paths to the set of versioned paths.
 
         Note that the command line normally calls smart_add instead,
@@ -92,50 +84,12 @@ class MutableTree(tree.Tree):
         This adds the files to the tree, so that they will be
         recorded by the next commit.
 
-        :param files: List of paths to add, relative to the base of the tree.
-        :param ids: If set, use these instead of automatically generated ids.
-            Must be the same length as the list of files, but may
-            contain None for ids that are to be autogenerated.
-        :param kinds: Optional parameter to specify the kinds to be used for
+        Args:
+          files: List of paths to add, relative to the base of the tree.
+          kinds: Optional parameter to specify the kinds to be used for
             each file.
-
-        TODO: Perhaps callback with the ids and paths as they're added.
         """
-        if isinstance(files, (str, text_type)):
-            # XXX: Passing a single string is inconsistent and should be
-            # deprecated.
-            if not (ids is None or isinstance(ids, bytes)):
-                raise AssertionError()
-            if not (kinds is None or isinstance(kinds, (str, text_type))):
-                raise AssertionError()
-            files = [files]
-            if ids is not None:
-                ids = [ids]
-            if kinds is not None:
-                kinds = [kinds]
-
-        files = [path.strip('/') for path in files]
-
-        if ids is None:
-            ids = [None] * len(files)
-        else:
-            if not (len(ids) == len(files)):
-                raise AssertionError()
-        if kinds is None:
-            kinds = [None] * len(files)
-        elif not len(kinds) == len(files):
-            raise AssertionError()
-        with self.lock_tree_write():
-            for f in files:
-                # generic constraint checks:
-                if self.is_control_filename(f):
-                    raise errors.ForbiddenControlFileError(filename=f)
-                fp = osutils.splitpath(f)
-            # fill out file kinds for all files [not needed when we stop
-            # caring about the instantaneous file kind within a uncommmitted tree
-            #
-            self._gather_kinds(files, kinds)
-            self._add(files, ids, kinds)
+        raise NotImplementedError(self.add)
 
     def add_reference(self, sub_tree):
         """Add a TreeReference to the tree, pointing at sub_tree.
@@ -144,44 +98,35 @@ class MutableTree(tree.Tree):
         """
         raise errors.UnsupportedOperation(self.add_reference, self)
 
-    def _add(self, files, ids, kinds):
-        """Helper function for add - updates the inventory.
-
-        :param files: sequence of pathnames, relative to the tree root
-        :param ids: sequence of suggested ids for the files (may be None)
-        :param kinds: sequence of  inventory kinds of the files (i.e. may
-            contain "tree-reference")
-        """
-        raise NotImplementedError(self._add)
-
     def commit(self, message=None, revprops=None, *args, **kwargs):
         # avoid circular imports
         from breezy import commit
+
         possible_master_transports = []
         with self.lock_write():
             revprops = commit.Commit.update_revprops(
                 revprops,
                 self.branch,
-                kwargs.pop('authors', None),
-                kwargs.get('local', False),
-                possible_master_transports)
+                kwargs.pop("authors", None),
+                kwargs.get("local", False),
+                possible_master_transports,
+            )
             # args for wt.commit start at message from the Commit.commit method,
-            args = (message, ) + args
-            for hook in MutableTree.hooks['start_commit']:
+            args = (message,) + args
+            for hook in MutableTree.hooks["start_commit"]:
                 hook(self)
-            committed_id = commit.Commit().commit(working_tree=self,
-                                                  revprops=revprops,
-                                                  possible_master_transports=possible_master_transports,
-                                                  *args, **kwargs)
+            committed_id = commit.Commit().commit(
+                working_tree=self,
+                revprops=revprops,
+                possible_master_transports=possible_master_transports,
+                *args,
+                **kwargs,
+            )
             post_hook_params = PostCommitHookParams(self)
-            for hook in MutableTree.hooks['post_commit']:
+            for hook in MutableTree.hooks["post_commit"]:
                 hook(post_hook_params)
             return committed_id
 
-    def _gather_kinds(self, files, kinds):
-        """Helper function for add - sets the entries of kinds."""
-        raise NotImplementedError(self._gather_kinds)
-
     def has_changes(self, _from_tree=None):
         """Quickly check that the tree contains at least one commitable change.
 
@@ -190,45 +135,9 @@ class MutableTree(tree.Tree):
 
         :return: True if a change is found. False otherwise
         """
-        with self.lock_read():
-            # Check pending merges
-            if len(self.get_parent_ids()) > 1:
-                return True
-            if _from_tree is None:
-                _from_tree = self.basis_tree()
-            changes = self.iter_changes(_from_tree)
-            if self.supports_symlinks():
-                # Fast path for has_changes.
-                try:
-                    change = next(changes)
-                    # Exclude root (talk about black magic... --vila 20090629)
-                    if change.parent_id == (None, None):
-                        change = next(changes)
-                    return True
-                except StopIteration:
-                    # No changes
-                    return False
-            else:
-                # Slow path for has_changes.
-                # Handle platforms that do not support symlinks in the
-                # conditional below. This is slower than the try/except
-                # approach below that but we don't have a choice as we
-                # need to be sure that all symlinks are removed from the
-                # entire changeset. This is because in platforms that
-                # do not support symlinks, they show up as None in the
-                # working copy as compared to the repository.
-                # Also, exclude root as mention in the above fast path.
-                changes = filter(
-                    lambda c: c[6][0] != 'symlink' and c[4] != (None, None),
-                    changes)
-                try:
-                    next(iter(changes))
-                except StopIteration:
-                    return False
-                return True
+        raise NotImplementedError(self.has_changes)
 
-    def check_changed_or_out_of_date(self, strict, opt_name,
-                                     more_error, more_warning):
+    def check_changed_or_out_of_date(self, strict, opt_name, more_error, more_warning):
         """Check the tree for uncommitted changes and branch synchronization.
 
         If strict is None and not set in the config files, a warning is issued.
@@ -248,7 +157,7 @@ class MutableTree(tree.Tree):
                 strict = self.branch.get_config_stack().get(opt_name)
             if strict is not False:
                 err_class = None
-                if (self.has_changes()):
+                if self.has_changes():
                     err_class = errors.UncommittedChanges
                 elif self.last_revision() != self.branch.last_revision():
                     # The tree has lost sync with its branch, there is little
@@ -260,7 +169,7 @@ class MutableTree(tree.Tree):
                         err = err_class(self, more=more_warning)
                         # We don't want to interrupt the user if he expressed
                         # no preference about strict.
-                        trace.warning('%s', err._format())
+                        trace.warning("%s", err._format())
                     else:
                         err = err_class(self, more=more_error)
                         raise err
@@ -300,11 +209,10 @@ class MutableTree(tree.Tree):
         """
         raise NotImplementedError(self.lock_write)
 
-    def mkdir(self, path, file_id=None):
-        """Create a directory in the tree. if file_id is None, one is assigned.
+    def mkdir(self, path):
+        """Create a directory in the tree.
 
         :param path: A unicode file path.
-        :param file_id: An optional file-id.
         :return: the file id of the new directory.
         """
         raise NotImplementedError(self.mkdir)
@@ -331,7 +239,7 @@ class MutableTree(tree.Tree):
         written to a temporary location and renamed. As a consequence,
         readers can potentially see the file half-written.
 
-        :param file_id: file-id of the file
+        :param path: path of the file
         :param bytes: the new file contents
         """
         raise NotImplementedError(self.put_file_bytes_non_atomic)
@@ -406,9 +314,9 @@ class MutableTree(tree.Tree):
         """
         raise NotImplementedError(self.copy_one)
 
-    def get_transform(self, pb=None):
+    def transform(self, pb=None):
         """Return a transform object for use with this tree."""
-        raise NotImplementedError(self.get_transform)
+        raise NotImplementedError(self.transform)
 
 
 class MutableTreeHooks(hooks.Hooks):
@@ -417,39 +325,50 @@ class MutableTreeHooks(hooks.Hooks):
     """
 
     def __init__(self):
-        """Create the default hooks.
-
-        """
+        """Create the default hooks."""
         hooks.Hooks.__init__(self, "breezy.mutabletree", "MutableTree.hooks")
-        self.add_hook('start_commit',
-                      "Called before a commit is performed on a tree. The start commit "
-                      "hook is able to change the tree before the commit takes place. "
-                      "start_commit is called with the breezy.mutabletree.MutableTree "
-                      "that the commit is being performed on.", (1, 4))
-        self.add_hook('post_commit',
-                      "Called after a commit is performed on a tree. The hook is "
-                      "called with a breezy.mutabletree.PostCommitHookParams object. "
-                      "The mutable tree the commit was performed on is available via "
-                      "the mutable_tree attribute of that object.", (2, 0))
-        self.add_hook('pre_transform',
-                      "Called before a tree transform on this tree. The hook is called "
-                      "with the tree that is being transformed and the transform.",
-                      (2, 5))
-        self.add_hook('post_build_tree',
-                      "Called after a completely new tree is built. The hook is "
-                      "called with the tree as its only argument.", (2, 5))
-        self.add_hook('post_transform',
-                      "Called after a tree transform has been performed on a tree. "
-                      "The hook is called with the tree that is being transformed and "
-                      "the transform.",
-                      (2, 5))
+        self.add_hook(
+            "start_commit",
+            "Called before a commit is performed on a tree. The start commit "
+            "hook is able to change the tree before the commit takes place. "
+            "start_commit is called with the breezy.mutabletree.MutableTree "
+            "that the commit is being performed on.",
+            (1, 4),
+        )
+        self.add_hook(
+            "post_commit",
+            "Called after a commit is performed on a tree. The hook is "
+            "called with a breezy.mutabletree.PostCommitHookParams object. "
+            "The mutable tree the commit was performed on is available via "
+            "the mutable_tree attribute of that object.",
+            (2, 0),
+        )
+        self.add_hook(
+            "pre_transform",
+            "Called before a tree transform on this tree. The hook is called "
+            "with the tree that is being transformed and the transform.",
+            (2, 5),
+        )
+        self.add_hook(
+            "post_build_tree",
+            "Called after a completely new tree is built. The hook is "
+            "called with the tree as its only argument.",
+            (2, 5),
+        )
+        self.add_hook(
+            "post_transform",
+            "Called after a tree transform has been performed on a tree. "
+            "The hook is called with the tree that is being transformed and "
+            "the transform.",
+            (2, 5),
+        )
 
 
 # install the default hooks into the MutableTree class.
-MutableTree.hooks = MutableTreeHooks()
+MutableTree.hooks = MutableTreeHooks()  # type: ignore
 
 
-class PostCommitHookParams(object):
+class PostCommitHookParams:
     """Parameters for the post_commit hook.
 
     To access the parameters, use the following attributes:
