@@ -14,32 +14,23 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-import os
-
-from breezy import (
-    merge,
-    osutils,
-    tests,
-    )
-from breezy.tests import (
-    features,
-    script,
-    )
 
+from breezy import merge, osutils
 from breezy.plugins import po_merge
+from breezy.tests import features, script
 
 
 class BlackboxTestPoMerger(script.TestCaseWithTransportAndScript):
-
     _test_needs_features = [features.msgmerge_feature]
 
     def setUp(self):
         super().setUp()
-        self.builder = make_adduser_branch(self, 'adduser')
+        self.builder = make_adduser_branch(self, "adduser")
         # We need to install our hook as the test framework cleared it as part
         # of the initialization
         merge.Merger.hooks.install_named_hook(
-            "merge_file_content", po_merge.po_merge_hook, ".po file merge")
+            "merge_file_content", po_merge.po_merge_hook, ".po file merge"
+        )
 
     def test_merge_with_hook_gives_unexpected_results(self):
         # Since the conflicts in .pot are not seen *during* the merge, the .po
@@ -71,8 +62,8 @@ $ brz merge ../adduser -rrevid:other -Opo_merge.po_dirs=
 2>2 conflicts encountered.
 """)
         # Fix the conflicts in the .pot file
-        with open('po/adduser.pot', 'wb') as f:
-            f.write(_Adduser['resolved_pot'])
+        with open("po/adduser.pot", "wb") as f:
+            f.write(_Adduser["resolved_pot"])
         # Tell brz the conflict is resolved
         self.run_script("""\
 $ brz resolve po/adduser.pot
@@ -93,27 +84,38 @@ def make_adduser_branch(test, relpath):
     """
     builder = test.make_branch_builder(relpath)
     builder.start_series()
-    builder.build_snapshot(None,
-                           [('add', ('', b'root-id', 'directory', '')),
-                            # Create empty files
-                            ('add', ('po', b'dir-id', 'directory', None),),
-                            ('add', ('po/adduser.pot', b'pot-id', 'file',
-                                     _Adduser['base_pot'])),
-                            ('add', ('po/fr.po', b'po-id', 'file',
-                                     _Adduser['base_po'])),
-                            ], revision_id=b'base')
+    builder.build_snapshot(
+        None,
+        [
+            ("add", ("", b"root-id", "directory", "")),
+            # Create empty files
+            (
+                "add",
+                ("po", b"dir-id", "directory", None),
+            ),
+            ("add", ("po/adduser.pot", b"pot-id", "file", _Adduser["base_pot"])),
+            ("add", ("po/fr.po", b"po-id", "file", _Adduser["base_po"])),
+        ],
+        revision_id=b"base",
+    )
     # The 'other' branch
-    builder.build_snapshot([b'base'],
-                           [('modify', ('po/adduser.pot',
-                                        _Adduser['other_pot'])),
-                            ('modify', ('po/fr.po',
-                                        _Adduser['other_po'])),
-                            ], revision_id=b'other')
+    builder.build_snapshot(
+        [b"base"],
+        [
+            ("modify", ("po/adduser.pot", _Adduser["other_pot"])),
+            ("modify", ("po/fr.po", _Adduser["other_po"])),
+        ],
+        revision_id=b"other",
+    )
     # The 'this' branch
-    builder.build_snapshot([b'base'],
-                           [('modify', ('po/adduser.pot', _Adduser['this_pot'])),
-                            ('modify', ('po/fr.po', _Adduser['this_po'])),
-                            ], revision_id=b'this')
+    builder.build_snapshot(
+        [b"base"],
+        [
+            ("modify", ("po/adduser.pot", _Adduser["this_pot"])),
+            ("modify", ("po/fr.po", _Adduser["this_po"])),
+        ],
+        revision_id=b"this",
+    )
     # builder.get_branch() tip is now 'this'
     builder.finish_series()
     return builder
@@ -124,34 +126,40 @@ class TestAdduserBranch(script.TestCaseWithTransportAndScript):
 
     def setUp(self):
         super().setUp()
-        self.builder = make_adduser_branch(self, 'adduser')
+        self.builder = make_adduser_branch(self, "adduser")
 
     def assertAdduserBranchContent(self, revid):
-        env = dict(revid=revid, branch_name=revid)
-        self.run_script("""\
-$ brz branch adduser -rrevid:%(revid)s %(branch_name)s
-""" % env, null_output_matches_anything=True)
-        self.assertFileEqual(_Adduser['%(revid)s_pot' % env],
-                             '%(branch_name)s/po/adduser.pot' % env)
-        self.assertFileEqual(_Adduser['%(revid)s_po' % env],
-                             '%(branch_name)s/po/fr.po' % env)
+        env = {"revid": revid, "branch_name": revid}
+        self.run_script(
+            """\
+$ brz branch adduser -rrevid:{revid} {branch_name}
+""".format(**env),
+            null_output_matches_anything=True,
+        )
+        self.assertFileEqual(
+            _Adduser["{revid}_pot".format(**env)],
+            "{branch_name}/po/adduser.pot".format(**env),
+        )
+        self.assertFileEqual(
+            _Adduser["{revid}_po".format(**env)], "{branch_name}/po/fr.po".format(**env)
+        )
 
     def test_base(self):
-        self.assertAdduserBranchContent('base')
+        self.assertAdduserBranchContent("base")
 
     def test_this(self):
-        self.assertAdduserBranchContent('this')
+        self.assertAdduserBranchContent("this")
 
     def test_other(self):
-        self.assertAdduserBranchContent('other')
+        self.assertAdduserBranchContent("other")
 
 
 # Real content from the adduser package so we don't have to guess about format
 # details. This is declared at the end of the file to avoid cluttering the
 # beginning of the file.
 
-_Adduser = dict(
-    base_pot=osutils.safe_utf8(r"""# SOME DESCRIPTIVE TITLE.
+_Adduser = {
+    "base_pot": osutils.safe_utf8(r"""# SOME DESCRIPTIVE TITLE.
 # Copyright (C) YEAR THE PACKAGE'S COPYRIGHT HOLDER
 # This file is distributed under the same license as the PACKAGE package.
 # FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.
@@ -179,7 +187,7 @@ msgid "Warning: The home dir you specified already exists.\n"
 msgstr ""
 
 """),
-    this_pot=osutils.safe_utf8(r"""# SOME DESCRIPTIVE TITLE.
+    "this_pot": osutils.safe_utf8(r"""# SOME DESCRIPTIVE TITLE.
 # Copyright (C) YEAR THE PACKAGE'S COPYRIGHT HOLDER
 # This file is distributed under the same license as the PACKAGE package.
 # FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.
@@ -214,7 +222,7 @@ msgid "Warning: The home dir %s you specified can't be accessed: %s\n"
 msgstr ""
 
 """),
-    other_pot=osutils.safe_utf8(r"""# SOME DESCRIPTIVE TITLE.
+    "other_pot": osutils.safe_utf8(r"""# SOME DESCRIPTIVE TITLE.
 # Copyright (C) YEAR THE PACKAGE'S COPYRIGHT HOLDER
 # This file is distributed under the same license as the PACKAGE package.
 # FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.
@@ -249,7 +257,7 @@ msgid "Warning: The home dir %s you specified can't be accessed: %s\n"
 msgstr ""
 
 """),
-    resolved_pot=osutils.safe_utf8(r"""# SOME DESCRIPTIVE TITLE.
+    "resolved_pot": osutils.safe_utf8(r"""# SOME DESCRIPTIVE TITLE.
 # Copyright (C) YEAR THE PACKAGE'S COPYRIGHT HOLDER
 # This file is distributed under the same license as the PACKAGE package.
 # FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.
@@ -284,7 +292,7 @@ msgid "Warning: The home dir %s you specified can't be accessed: %s\n"
 msgstr ""
 
 """),
-    base_po=osutils.safe_utf8(r"""# adduser's manpages translation to French
+    "base_po": osutils.safe_utf8(r"""# adduser's manpages translation to French
 # Copyright (C) 2004 Software in the Public Interest
 # This file is distributed under the same license as the adduser package
 #
@@ -320,7 +328,7 @@ msgstr ""
 "Attention ! Le répertoire personnel que vous avez indiqué existe déjà.\n"
 
 """),
-    this_po=osutils.safe_utf8(r"""# adduser's manpages translation to French
+    "this_po": osutils.safe_utf8(r"""# adduser's manpages translation to French
 # Copyright (C) 2004 Software in the Public Interest
 # This file is distributed under the same license as the adduser package
 #
@@ -363,7 +371,7 @@ msgstr ""
 "Attention ! Le répertoire personnel que vous avez indiqué existe déjà.\n"
 
 """),
-    other_po=osutils.safe_utf8(r"""# adduser's manpages translation to French
+    "other_po": osutils.safe_utf8(r"""# adduser's manpages translation to French
 # Copyright (C) 2004 Software in the Public Interest
 # This file is distributed under the same license as the adduser package
 #
@@ -406,7 +414,7 @@ msgstr ""
 "indiqué (%s) : %s.\n"
 
 """),
-    resolved_po=osutils.safe_utf8(r"""# adduser's manpages translation to French
+    "resolved_po": osutils.safe_utf8(r"""# adduser's manpages translation to French
 # Copyright (C) 2004 Software in the Public Interest
 # This file is distributed under the same license as the adduser package
 #
@@ -449,4 +457,4 @@ msgstr ""
 "indiqué (%s) : %s.\n"
 
 """),
-)
+}
