@@ -27,8 +27,7 @@ import os
 import resource
 import sys
 
-from breezy import osutils, tests
-from breezy.tests import features, script
+from breezy import tests
 
 BIG_FILE_SIZE = 1024 * 1024 * 500
 BIG_FILE_CHUNK_SIZE = 1024
@@ -38,10 +37,10 @@ LIMIT = 1024 * 1024 * 100
 
 
 def make_big_file(path):
-    blob_1mb = BIG_FILE_CHUNK_SIZE * b'\x0c'
+    blob_1mb = BIG_FILE_CHUNK_SIZE * b"\x0c"
     fd = os.open(path, os.O_CREAT | os.O_WRONLY)
     try:
-        for i in range(BIG_FILE_SIZE // BIG_FILE_CHUNK_SIZE):
+        for _i in range(BIG_FILE_SIZE // BIG_FILE_CHUNK_SIZE):
             os.write(fd, blob_1mb)
     finally:
         os.close(fd)
@@ -49,7 +48,7 @@ def make_big_file(path):
 
 @contextlib.contextmanager
 def limit_memory(size):
-    if sys.platform in ('win32', 'darwin'):
+    if sys.platform in ("win32", "darwin"):
         raise NotImplementedError
     previous = resource.getrlimit(RESOURCE)
     resource.setrlimit(RESOURCE, (LIMIT, -1))
@@ -58,14 +57,13 @@ def limit_memory(size):
 
 
 class TestAdd(tests.TestCaseWithTransport):
-
     def writeBigFile(self, path):
         self.addCleanup(os.unlink, path)
         try:
             make_big_file(path)
         except OSError as e:
             if e.errno == errno.ENOSPC:
-                self.skipTest('not enough disk space for big file')
+                self.skipTest("not enough disk space for big file")
 
     def setUp(self):
         super().setUp()
@@ -73,40 +71,41 @@ class TestAdd(tests.TestCaseWithTransport):
         try:
             cm.__enter__()
         except NotImplementedError:
-            self.skipTest('memory limits not supported on this platform')
+            self.skipTest("memory limits not supported on this platform")
         self.addCleanup(cm.__exit__, None, None, None)
 
     def test_allocate(self):
         def allocate():
             "." * BIG_FILE_SIZE
+
         self.assertRaises(MemoryError, allocate)
 
     def test_add(self):
-        tree = self.make_branch_and_tree('tree')
-        self.writeBigFile(os.path.join(tree.basedir, 'testfile'))
-        tree.add('testfile')
+        tree = self.make_branch_and_tree("tree")
+        self.writeBigFile(os.path.join(tree.basedir, "testfile"))
+        tree.add("testfile")
 
     def test_make_file_big(self):
-        self.knownFailure('commit keeps entire files in memory')
-        tree = self.make_branch_and_tree('tree')
-        self.build_tree(['tree/testfile'])
-        tree.add('testfile')
-        tree.commit('add small file')
-        self.writeBigFile(os.path.join(tree.basedir, 'testfile'))
-        tree.commit('small files get big')
-        self.knownFailure('commit keeps entire files in memory')
+        self.knownFailure("commit keeps entire files in memory")
+        tree = self.make_branch_and_tree("tree")
+        self.build_tree(["tree/testfile"])
+        tree.add("testfile")
+        tree.commit("add small file")
+        self.writeBigFile(os.path.join(tree.basedir, "testfile"))
+        tree.commit("small files get big")
+        self.knownFailure("commit keeps entire files in memory")
 
     def test_commit(self):
-        self.knownFailure('commit keeps entire files in memory')
-        tree = self.make_branch_and_tree('tree')
-        self.writeBigFile(os.path.join(tree.basedir, 'testfile'))
-        tree.add('testfile')
-        tree.commit('foo')
+        self.knownFailure("commit keeps entire files in memory")
+        tree = self.make_branch_and_tree("tree")
+        self.writeBigFile(os.path.join(tree.basedir, "testfile"))
+        tree.add("testfile")
+        tree.commit("foo")
 
     def test_clone(self):
-        self.knownFailure('commit keeps entire files in memory')
-        tree = self.make_branch_and_tree('tree')
-        self.writeBigFile(os.path.join(tree.basedir, 'testfile'))
-        tree.add('testfile')
-        tree.commit('foo')
-        tree.clone.sprout('newtree')
+        self.knownFailure("commit keeps entire files in memory")
+        tree = self.make_branch_and_tree("tree")
+        self.writeBigFile(os.path.join(tree.basedir, "testfile"))
+        tree.add("testfile")
+        tree.commit("foo")
+        tree.clone.sprout("newtree")
