@@ -15,8 +15,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 
-"""Black-box tests for brz re-sign.
-"""
+"""Black-box tests for brz re-sign."""
 
 from breezy import gpg, tests
 from breezy.bzr.testament import Testament
@@ -24,7 +23,6 @@ from breezy.controldir import ControlDir
 
 
 class ReSign(tests.TestCaseInTempDir):
-
     def monkey_patch_gpg(self):
         """Monkey patch the gpg signing strategy to be a loopback.
 
@@ -32,10 +30,10 @@ class ReSign(tests.TestCaseInTempDir):
         the original gpg strategy when done.
         """
         # monkey patch gpg signing mechanism
-        self.overrideAttr(gpg, 'GPGStrategy', gpg.LoopbackGPGStrategy)
+        self.overrideAttr(gpg, "GPGStrategy", gpg.LoopbackGPGStrategy)
 
     def setup_tree(self):
-        wt = ControlDir.create_standalone_workingtree('.')
+        wt = ControlDir.create_standalone_workingtree(".")
         a = wt.commit("base A", allow_pointless=True)
         b = wt.commit("base B", allow_pointless=True)
         c = wt.commit("base C", allow_pointless=True)
@@ -45,10 +43,11 @@ class ReSign(tests.TestCaseInTempDir):
     def assertEqualSignature(self, repo, revision_id):
         """Assert a signature is stored correctly in repository."""
         self.assertEqual(
-            b'-----BEGIN PSEUDO-SIGNED CONTENT-----\n' +
-            Testament.from_revision(repo, revision_id).as_short_text() +
-            b'-----END PSEUDO-SIGNED CONTENT-----\n',
-            repo.get_signature_text(revision_id))
+            b"-----BEGIN PSEUDO-SIGNED CONTENT-----\n"
+            + Testament.from_revision(repo, revision_id).as_short_text()
+            + b"-----END PSEUDO-SIGNED CONTENT-----\n",
+            repo.get_signature_text(revision_id),
+        )
 
     def test_resign(self):
         # Test re signing of data.
@@ -56,11 +55,11 @@ class ReSign(tests.TestCaseInTempDir):
         repo = wt.branch.repository
 
         self.monkey_patch_gpg()
-        self.run_bzr('re-sign -r revid:%s' % a.decode('utf-8'))
+        self.run_bzr("re-sign -r revid:{}".format(a.decode("utf-8")))
 
         self.assertEqualSignature(repo, a)
 
-        self.run_bzr('re-sign %s' % b.decode('utf-8'))
+        self.run_bzr("re-sign {}".format(b.decode("utf-8")))
         self.assertEqualSignature(repo, b)
 
     def test_resign_range(self):
@@ -68,7 +67,7 @@ class ReSign(tests.TestCaseInTempDir):
         repo = wt.branch.repository
 
         self.monkey_patch_gpg()
-        self.run_bzr('re-sign -r 1..')
+        self.run_bzr("re-sign -r 1..")
         self.assertEqualSignature(repo, a)
         self.assertEqualSignature(repo, b)
         self.assertEqualSignature(repo, c)
@@ -78,20 +77,19 @@ class ReSign(tests.TestCaseInTempDir):
         repo = wt.branch.repository
 
         self.monkey_patch_gpg()
-        self.run_bzr('re-sign ' + ' '.join(
-            r.decode('utf-8') for r in rs))
+        self.run_bzr("re-sign " + " ".join(r.decode("utf-8") for r in rs))
         for r in rs:
             self.assertEqualSignature(repo, r)
 
     def test_resign_directory(self):
-        """Test --directory option"""
-        wt = ControlDir.create_standalone_workingtree('a')
+        """Test --directory option."""
+        wt = ControlDir.create_standalone_workingtree("a")
         a = wt.commit("base A", allow_pointless=True)
         b = wt.commit("base B", allow_pointless=True)
-        c = wt.commit("base C", allow_pointless=True)
+        wt.commit("base C", allow_pointless=True)
         repo = wt.branch.repository
         self.monkey_patch_gpg()
-        self.run_bzr('re-sign --directory=a -r revid:' + a.decode('utf-8'))
+        self.run_bzr("re-sign --directory=a -r revid:" + a.decode("utf-8"))
         self.assertEqualSignature(repo, a)
-        self.run_bzr('re-sign -d a %s' % b.decode('utf-8'))
+        self.run_bzr("re-sign -d a {}".format(b.decode("utf-8")))
         self.assertEqualSignature(repo, b)
