@@ -14,27 +14,28 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-"""Black-box tests for repositories with shared branches"""
+"""Black-box tests for repositories with shared branches."""
 
 import os
 
+import breezy.errors as errors
 from breezy.bzr.bzrdir import BzrDirMetaFormat1
 from breezy.controldir import ControlDir
-import breezy.errors as errors
 from breezy.tests import TestCaseInTempDir
 
 
 class TestSharedRepo(TestCaseInTempDir):
-
     def test_make_repository(self):
         out, err = self.run_bzr("init-shared-repository a")
-        self.assertEqual(out,
-                         """Shared repository with trees (format: 2a)
+        self.assertEqual(
+            out,
+            """Shared repository with trees (format: 2a)
 Location:
   shared repository: a
-""")
+""",
+        )
         self.assertEqual(err, "")
-        dir = ControlDir.open('a')
+        dir = ControlDir.open("a")
         self.assertIs(dir.open_repository().is_shared(), True)
         self.assertRaises(errors.NotBranchError, dir.open_branch)
         self.assertRaises(errors.NoWorkingTree, dir.open_workingtree)
@@ -43,7 +44,7 @@ Location:
         out, err = self.run_bzr("init-shared-repository a -q")
         self.assertEqual(out, "")
         self.assertEqual(err, "")
-        dir = ControlDir.open('a')
+        dir = ControlDir.open("a")
         self.assertIs(dir.open_repository().is_shared(), True)
         self.assertRaises(errors.NotBranchError, dir.open_branch)
         self.assertRaises(errors.NoWorkingTree, dir.open_workingtree)
@@ -54,26 +55,26 @@ Location:
         (Malone #38331)
         """
         out, err = self.run_bzr("init-shared-repository .")
-        dir = ControlDir.open('.')
+        dir = ControlDir.open(".")
         self.assertTrue(dir.open_repository())
 
     def test_init(self):
         self.run_bzr("init-shared-repo a")
         self.run_bzr("init --format=default a/b")
-        dir = ControlDir.open('a')
+        dir = ControlDir.open("a")
         self.assertIs(dir.open_repository().is_shared(), True)
         self.assertRaises(errors.NotBranchError, dir.open_branch)
         self.assertRaises(errors.NoWorkingTree, dir.open_workingtree)
-        bdir = ControlDir.open('a/b')
+        bdir = ControlDir.open("a/b")
         bdir.open_branch()
         self.assertRaises(errors.NoRepositoryPresent, bdir.open_repository)
-        wt = bdir.open_workingtree()
+        bdir.open_workingtree()
 
     def test_branch(self):
         self.run_bzr("init-shared-repo a")
         self.run_bzr("init --format=default a/b")
-        self.run_bzr('branch a/b a/c')
-        cdir = ControlDir.open('a/c')
+        self.run_bzr("branch a/b a/c")
+        cdir = ControlDir.open("a/c")
         cdir.open_branch()
         self.assertRaises(errors.NoRepositoryPresent, cdir.open_repository)
         cdir.open_workingtree()
@@ -81,16 +82,16 @@ Location:
     def test_branch_tree(self):
         self.run_bzr("init-shared-repo --trees a")
         self.run_bzr("init --format=default b")
-        with open('b/hello', 'w') as f:
-            f.write('bar')
+        with open("b/hello", "w") as f:
+            f.write("bar")
         self.run_bzr("add b/hello")
         self.run_bzr("commit -m bar b/hello")
 
-        self.run_bzr('branch b a/c')
-        cdir = ControlDir.open('a/c')
+        self.run_bzr("branch b a/c")
+        cdir = ControlDir.open("a/c")
         cdir.open_branch()
         self.assertRaises(errors.NoRepositoryPresent, cdir.open_repository)
-        self.assertPathExists('a/c/hello')
+        self.assertPathExists("a/c/hello")
         cdir.open_workingtree()
 
     def test_trees_default(self):
@@ -116,7 +117,7 @@ Location:
         out, err = self.run_bzr("init-shared-repository -q a")
         self.assertEqual(out, "")
         self.assertEqual(err, "")
-        dir = ControlDir.open('a')
+        dir = ControlDir.open("a")
         dir.open_repository()  # there is a repository there
         e = self.assertRaises(errors.NotBranchError, dir.open_branch)
         self.assertContainsRe(str(e), "location is a repository")
@@ -124,30 +125,28 @@ Location:
     def test_notification_on_branch_from_nonrepository(self):
         fmt = BzrDirMetaFormat1()
         t = self.get_transport()
-        t.mkdir('a')
-        dir = fmt.initialize_on_transport(t.clone('a'))
+        t.mkdir("a")
+        dir = fmt.initialize_on_transport(t.clone("a"))
         self.assertRaises(errors.NoRepositoryPresent, dir.open_repository)
         e = self.assertRaises(errors.NotBranchError, dir.open_branch)
         self.assertNotContainsRe(str(e), "location is a repository")
 
     def test_init_repo_with_post_repo_init_hook(self):
         calls = []
-        ControlDir.hooks.install_named_hook(
-            'post_repo_init', calls.append, None)
+        ControlDir.hooks.install_named_hook("post_repo_init", calls.append, None)
         self.assertLength(0, calls)
         self.run_bzr("init-shared-repository a")
         self.assertLength(1, calls)
 
     def test_init_repo_without_username(self):
-        """Ensure init-shared-repo works if username is not set.
-        """
+        """Ensure init-shared-repo works if username is not set."""
         # brz makes user specified whoami mandatory for operations
         # like commit as whoami is recorded. init-shared-repo however is not so
         # final and uses whoami only in a lock file. Without whoami the login name
         # is used. This test is to ensure that init-shared-repo passes even
         # when whoami is not available.
-        self.overrideEnv('EMAIL', None)
-        self.overrideEnv('BRZ_EMAIL', None)
-        out, err = self.run_bzr(['init-shared-repo', 'foo'])
-        self.assertEqual(err, '')
-        self.assertTrue(os.path.exists('foo'))
+        self.overrideEnv("EMAIL", None)
+        self.overrideEnv("BRZ_EMAIL", None)
+        out, err = self.run_bzr(["init-shared-repo", "foo"])
+        self.assertEqual(err, "")
+        self.assertTrue(os.path.exists("foo"))
