@@ -21,33 +21,31 @@ from breezy.tests import TestCaseWithTransport
 
 
 class TestUnknowns(TestCaseWithTransport):
-
     def test_unknowns(self):
-        """Test that 'unknown' command reports unknown files"""
-
+        """Test that 'unknown' command reports unknown files."""
         # in empty directory, no unknowns
-        tree = self.make_branch_and_tree('.')
-        self.assertEqual(self.run_bzr('unknowns')[0], '')
+        tree = self.make_branch_and_tree(".")
+        self.assertEqual(self.run_bzr("unknowns")[0], "")
 
         # single unknown file
-        self.build_tree_contents([('a', b'contents of a\n')])
-        self.assertEqual(self.run_bzr('unknowns')[0], 'a\n')
+        self.build_tree_contents([("a", b"contents of a\n")])
+        self.assertEqual(self.run_bzr("unknowns")[0], "a\n")
 
         # multiple unknown files, including one with a space in its name
-        self.build_tree(['b', 'c', 'd e'])
-        self.assertEqual(self.run_bzr('unknowns')[0], 'a\nb\nc\n"d e"\n')
+        self.build_tree(["b", "c", "d e"])
+        self.assertEqual(self.run_bzr("unknowns")[0], 'a\nb\nc\n"d e"\n')
 
         # after add, file no longer shown
-        tree.add(['a', 'd e'])
-        self.assertEqual(self.run_bzr('unknowns')[0], 'b\nc\n')
+        tree.add(["a", "d e"])
+        self.assertEqual(self.run_bzr("unknowns")[0], "b\nc\n")
 
         # after all added, none shown
-        tree.add(['b', 'c'])
-        self.assertEqual(self.run_bzr('unknowns')[0], '')
+        tree.add(["b", "c"])
+        self.assertEqual(self.run_bzr("unknowns")[0], "")
 
     def test_unknowns_directory(self):
-        """Test --directory option"""
-        tree = self.make_branch_and_tree('a')
-        self.build_tree(['a/README'])
-        out, err = self.run_bzr(['unknowns', '--directory=a'])
-        self.assertEqual('README\n', out)
+        """Test --directory option."""
+        self.make_branch_and_tree("a")
+        self.build_tree(["a/README"])
+        out, err = self.run_bzr(["unknowns", "--directory=a"])
+        self.assertEqual("README\n", out)
