@@ -15,65 +15,55 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 
-import doctest
 import os
 import sys
+from io import StringIO
 
 import breezy
-from .. import (
-    bedding,
-    crash,
-    osutils,
-    plugin,
-    tests,
-    )
-from ..sixish import (
-    StringIO,
-    )
+
+from .. import bedding, crash, osutils, plugin, tests
 from . import features
 
 
 class TestApportReporting(tests.TestCaseInTempDir):
-
     _test_needs_features = [features.apport]
 
     def test_apport_report(self):
-        crash_dir = osutils.joinpath((self.test_base_dir, 'crash'))
+        crash_dir = osutils.joinpath((self.test_base_dir, "crash"))
         os.mkdir(crash_dir)
-        self.overrideEnv('APPORT_CRASH_DIR', crash_dir)
+        self.overrideEnv("APPORT_CRASH_DIR", crash_dir)
         self.assertEqual(crash_dir, bedding.crash_dir())
 
         self.overrideAttr(
             breezy.get_global_state(),
-            'plugin_warnings',
-            {'example': ['Failed to load plugin foo']})
+            "plugin_warnings",
+            {"example": ["Failed to load plugin foo"]},
+        )
 
         stderr = StringIO()
 
         try:
             raise AssertionError("my error")
-        except AssertionError as e:
+        except AssertionError:
             crash_filename = crash.report_bug_to_apport(sys.exc_info(), stderr)
 
         # message explaining the crash
-        self.assertContainsRe(stderr.getvalue(),
-                              "    apport-bug %s" % crash_filename)
+        self.assertContainsRe(
+            stderr.getvalue(), "    apport-bug {}".format(crash_filename)
+        )
 
         with open(crash_filename) as crash_file:
             report = crash_file.read()
 
-        self.assertContainsRe(report,
-                              '(?m)^BrzVersion:')  # should be in the traceback
-        self.assertContainsRe(report, 'my error')
-        self.assertContainsRe(report, 'AssertionError')
+        self.assertContainsRe(report, "(?m)^BrzVersion:")  # should be in the traceback
+        self.assertContainsRe(report, "my error")
+        self.assertContainsRe(report, "AssertionError")
         # see https://bugs.launchpad.net/bzr/+bug/528114
-        self.assertContainsRe(report, 'ExecutablePath')
-        self.assertContainsRe(report, 'test_apport_report')
+        self.assertContainsRe(report, "ExecutablePath")
+        self.assertContainsRe(report, "test_apport_report")
         # should also be in there
-        self.assertContainsRe(report, '(?m)^CommandLine:')
-        self.assertContainsRe(
-            report,
-            'Failed to load plugin foo')
+        self.assertContainsRe(report, "(?m)^CommandLine:")
+        self.assertContainsRe(report, "Failed to load plugin foo")
 
 
 class TestNonApportReporting(tests.TestCase):
@@ -83,22 +73,22 @@ class TestNonApportReporting(tests.TestCase):
     """
 
     def setup_fake_plugins(self):
-        fake = plugin.PlugIn('fake_plugin', plugin)
+        fake = plugin.PlugIn("fake_plugin", plugin)
         fake.version_info = lambda: (1, 2, 3)
         fake_plugins = {"fake_plugin": fake}
-        self.overrideAttr(breezy.get_global_state(), 'plugins', fake_plugins)
+        self.overrideAttr(breezy.get_global_state(), "plugins", fake_plugins)
 
     def test_report_bug_legacy(self):
         self.setup_fake_plugins()
         err_file = StringIO()
         try:
             raise AssertionError("my error")
-        except AssertionError as e:
+        except AssertionError:
             crash.report_bug_legacy(sys.exc_info(), err_file)
         report = err_file.getvalue()
         for needle in [
-                "brz: ERROR: AssertionError: my error",
-                r"Traceback \(most recent call last\):",
-                r"plugins: fake_plugin\[1\.2\.3\]",
-                ]:
+            "brz: ERROR: AssertionError: my error",
+            r"Traceback \(most recent call last\):",
+            r"plugins: fake_plugin\[1\.2\.3\]",
+        ]:
             self.assertContainsRe(report, needle)
