@@ -37,23 +37,14 @@ Some properties are common to all kinds:
   InvalidHttpResponse.
 """
 
-from io import BytesIO
-
 import http.client as http_client
+from io import BytesIO
 
 parse_headers = http_client.parse_headers
 
-from .. import (
-    errors,
-    tests,
-    )
-from ..transport.http import (
-    response,
-    urllib,
-    )
-from .file_utils import (
-    FakeReadFile,
-    )
+from .. import errors, tests
+from ..transport.http import response, urllib
+from .file_utils import FakeReadFile
 
 
 class ReadSocket:
@@ -62,14 +53,13 @@ class ReadSocket:
     def __init__(self, data):
         self.readfile = BytesIO(data)
 
-    def makefile(self, mode='r', bufsize=None):
+    def makefile(self, mode="r", bufsize=None):
         return self.readfile
 
 
 class FakeHTTPConnection(urllib.HTTPConnection):
-
     def __init__(self, sock):
-        urllib.HTTPConnection.__init__(self, 'localhost')
+        urllib.HTTPConnection.__init__(self, "localhost")
         # Set the socket to bypass the connection
         self.sock = sock
 
@@ -79,22 +69,20 @@ class FakeHTTPConnection(urllib.HTTPConnection):
 
 
 class TestResponseFileIter(tests.TestCase):
-
     def test_iter_empty(self):
-        f = response.ResponseFile('empty', BytesIO())
+        f = response.ResponseFile("empty", BytesIO())
         self.assertEqual([], list(f))
 
     def test_iter_many(self):
-        f = response.ResponseFile('many', BytesIO(b'0\n1\nboo!\n'))
-        self.assertEqual([b'0\n', b'1\n', b'boo!\n'], list(f))
+        f = response.ResponseFile("many", BytesIO(b"0\n1\nboo!\n"))
+        self.assertEqual([b"0\n", b"1\n", b"boo!\n"], list(f))
 
     def test_readlines(self):
-        f = response.ResponseFile('many', BytesIO(b'0\n1\nboo!\n'))
-        self.assertEqual([b'0\n', b'1\n', b'boo!\n'], f.readlines())
+        f = response.ResponseFile("many", BytesIO(b"0\n1\nboo!\n"))
+        self.assertEqual([b"0\n", b"1\n", b"boo!\n"], f.readlines())
 
 
 class TestHTTPConnection(tests.TestCase):
-
     def test_cleanup_pipe(self):
         sock = ReadSocket(b"""HTTP/1.1 200 OK\r
 Content-Type: text/plain; charset=UTF-8\r
@@ -105,16 +93,16 @@ garbage""")
         conn = FakeHTTPConnection(sock)
         # Simulate the request sending so that the connection will be able to
         # read the response.
-        conn.putrequest('GET', 'http://localhost/fictious')
+        conn.putrequest("GET", "http://localhost/fictious")
         conn.endheaders()
         # Now, get the response
         resp = conn.getresponse()
         # Read part of the response
-        self.assertEqual(b'0123456789\n', resp.read(11))
+        self.assertEqual(b"0123456789\n", resp.read(11))
         # Override the thresold to force the warning emission
         conn._range_warning_thresold = 6  # There are 7 bytes pending
         conn.cleanup_pipe()
-        self.assertContainsRe(self.get_log(), 'Got a 200 response when asking')
+        self.assertContainsRe(self.get_log(), "Got a 200 response when asking")
 
 
 class TestRangeFileMixin:
@@ -124,7 +112,7 @@ class TestRangeFileMixin:
     # which offsets are easy to calculate for test writers. It's used as a
     # building block with slight variations but basically 'a' is the first char
     # of the range and 'z' is the last.
-    alpha = b'abcdefghijklmnopqrstuvwxyz'
+    alpha = b"abcdefghijklmnopqrstuvwxyz"
 
     def test_can_read_at_first_access(self):
         """Test that the just created file can be read."""
@@ -139,14 +127,14 @@ class TestRangeFileMixin:
         cur = start  # For an overall offset assertion
         f.seek(start + 3)
         cur += 3
-        self.assertEqual(b'def', f.read(3))
-        cur += len('def')
+        self.assertEqual(b"def", f.read(3))
+        cur += len("def")
         f.seek(4, 1)
         cur += 4
-        self.assertEqual(b'klmn', f.read(4))
-        cur += len('klmn')
+        self.assertEqual(b"klmn", f.read(4))
+        cur += len("klmn")
         # read(0) in the middle of a range
-        self.assertEqual(b'', f.read(0))
+        self.assertEqual(b"", f.read(0))
         # seek in place
         here = f.tell()
         f.seek(0, 1)
@@ -155,9 +143,9 @@ class TestRangeFileMixin:
 
     def test_read_zero(self):
         f = self._file
-        self.assertEqual(b'', f.read(0))
+        self.assertEqual(b"", f.read(0))
         f.seek(10, 1)
-        self.assertEqual(b'', f.read(0))
+        self.assertEqual(b"", f.read(0))
 
     def test_seek_at_range_end(self):
         f = self._file
@@ -167,14 +155,14 @@ class TestRangeFileMixin:
         """Test read behaviour at range end."""
         f = self._file
         self.assertEqual(self.alpha, f.read())
-        self.assertEqual(b'', f.read(0))
+        self.assertEqual(b"", f.read(0))
         self.assertRaises(errors.InvalidRange, f.read, 1)
 
     def test_unbounded_read_after_seek(self):
         f = self._file
         f.seek(24, 1)
         # Should not cross ranges
-        self.assertEqual(b'yz', f.read())
+        self.assertEqual(b"yz", f.read())
 
     def test_seek_backwards(self):
         f = self._file
@@ -186,10 +174,9 @@ class TestRangeFileMixin:
     def test_seek_outside_single_range(self):
         f = self._file
         if f._size == -1 or f._boundary is not None:
-            raise tests.TestNotApplicable('Needs a fully defined range')
+            raise tests.TestNotApplicable("Needs a fully defined range")
         # Will seek past the range and then errors out
-        self.assertRaises(errors.InvalidRange,
-                          f.seek, self.first_range_start + 27)
+        self.assertRaises(errors.InvalidRange, f.seek, self.first_range_start + 27)
 
     def test_read_past_end_of_range(self):
         f = self._file
@@ -214,7 +201,7 @@ class TestRangeFileMixin:
         """
         f = self._file
         f.seek(-2, 2)
-        self.assertEqual(b'yz', f.read())
+        self.assertEqual(b"yz", f.read())
 
 
 class TestRangeFileSizeUnknown(tests.TestCase, TestRangeFileMixin):
@@ -222,8 +209,7 @@ class TestRangeFileSizeUnknown(tests.TestCase, TestRangeFileMixin):
 
     def setUp(self):
         super().setUp()
-        self._file = response.RangeFile('Whole_file_size_known',
-                                        BytesIO(self.alpha))
+        self._file = response.RangeFile("Whole_file_size_known", BytesIO(self.alpha))
         # We define no range, relying on RangeFile to provide default values
         self.first_range_start = 0  # It's the whole file
 
@@ -238,8 +224,8 @@ class TestRangeFileSizeUnknown(tests.TestCase, TestRangeFileMixin):
         """Test read behaviour at range end."""
         f = self._file
         self.assertEqual(self.alpha, f.read())
-        self.assertEqual(b'', f.read(0))
-        self.assertEqual(b'', f.read(1))
+        self.assertEqual(b"", f.read(0))
+        self.assertEqual(b"", f.read(1))
 
 
 class TestRangeFileSizeKnown(tests.TestCase, TestRangeFileMixin):
@@ -247,8 +233,7 @@ class TestRangeFileSizeKnown(tests.TestCase, TestRangeFileMixin):
 
     def setUp(self):
         super().setUp()
-        self._file = response.RangeFile('Whole_file_size_known',
-                                        BytesIO(self.alpha))
+        self._file = response.RangeFile("Whole_file_size_known", BytesIO(self.alpha))
         self._file.set_range(0, len(self.alpha))
         self.first_range_start = 0  # It's the whole file
 
@@ -258,8 +243,7 @@ class TestRangeFileSingleRange(tests.TestCase, TestRangeFileMixin):
 
     def setUp(self):
         super().setUp()
-        self._file = response.RangeFile('Single_range_file',
-                                        BytesIO(self.alpha))
+        self._file = response.RangeFile("Single_range_file", BytesIO(self.alpha))
         self.first_range_start = 15
         self._file.set_range(self.first_range_start, len(self.alpha))
 
@@ -294,25 +278,25 @@ class TestRangeFileMultipleRanges(tests.TestCase, TestRangeFileMixin):
 
         boundary = self.boundary
 
-        content = b''
+        content = b""
         self.first_range_start = 25
         file_size = 200  # big enough to encompass all ranges
-        for (start, part) in [(self.first_range_start, self.alpha),
-                              # Two contiguous ranges
-                              (100, self.alpha),
-                              (126, self.alpha.upper())]:
-            content += self._multipart_byterange(part, start, boundary,
-                                                 file_size)
+        for start, part in [
+            (self.first_range_start, self.alpha),
+            # Two contiguous ranges
+            (100, self.alpha),
+            (126, self.alpha.upper()),
+        ]:
+            content += self._multipart_byterange(part, start, boundary, file_size)
         # Final boundary
         content += self._boundary_line()
 
-        self._file = response.RangeFile('Multiple_ranges_file',
-                                        BytesIO(content))
+        self._file = response.RangeFile("Multiple_ranges_file", BytesIO(content))
         self.set_file_boundary()
 
     def _boundary_line(self):
         """Helper to build the formatted boundary line."""
-        return b'--' + self.boundary + b'\r\n'
+        return b"--" + self.boundary + b"\r\n"
 
     def set_file_boundary(self):
         # Ranges are set by decoding the range headers, the RangeFile user is
@@ -321,7 +305,7 @@ class TestRangeFileMultipleRanges(tests.TestCase, TestRangeFileMixin):
         # which is part of the Content-Type header).
         self._file.set_boundary(self.boundary)
 
-    def _multipart_byterange(self, data, offset, boundary, file_size=b'*'):
+    def _multipart_byterange(self, data, offset, boundary, file_size=b"*"):
         """Encode a part of a file as a multipart/byterange MIME type.
 
         When a range request is issued, the HTTP response body can be
@@ -344,12 +328,13 @@ class TestRangeFileMultipleRanges(tests.TestCase, TestRangeFileMixin):
         # required for our implementation (TestHandleResponse below will
         # exercise ranges with multiple or missing headers')
         if isinstance(file_size, int):
-            file_size = b'%d' % file_size
-        range += b'Content-Range: bytes %d-%d/%s\r\n' % (offset,
-                                                         offset +
-                                                         len(data) - 1,
-                                                         file_size)
-        range += b'\r\n'
+            file_size = b"%d" % file_size
+        range += b"Content-Range: bytes %d-%d/%s\r\n" % (
+            offset,
+            offset + len(data) - 1,
+            file_size,
+        )
+        range += b"\r\n"
         # Finally the raw bytes
         range += data
         return range
@@ -361,9 +346,9 @@ class TestRangeFileMultipleRanges(tests.TestCase, TestRangeFileMixin):
         self.assertEqual(self.alpha, f.read())  # Read second range
         self.assertEqual(126, f.tell())
         f.seek(126)  # Start of third range which is also the current pos !
-        self.assertEqual(b'A', f.read(1))
+        self.assertEqual(b"A", f.read(1))
         f.seek(10, 1)
-        self.assertEqual(b'LMN', f.read(3))
+        self.assertEqual(b"LMN", f.read(3))
 
     def test_seek_from_end(self):
         """See TestRangeFileMixin.test_seek_from_end."""
@@ -373,7 +358,7 @@ class TestRangeFileMultipleRanges(tests.TestCase, TestRangeFileMixin):
         # behaviour.
         f = self._file
         f.seek(-2, 2)
-        self.assertEqual(b'yz', f.read())
+        self.assertEqual(b"yz", f.read())
         self.assertRaises(errors.InvalidRange, f.seek, -2, 2)
 
     def test_seek_into_void(self):
@@ -391,14 +376,14 @@ class TestRangeFileMultipleRanges(tests.TestCase, TestRangeFileMixin):
     def test_seek_across_ranges(self):
         f = self._file
         f.seek(126)  # skip the two first ranges
-        self.assertEqual(b'AB', f.read(2))
+        self.assertEqual(b"AB", f.read(2))
 
     def test_checked_read_dont_overflow_buffers(self):
         f = self._file
         # We force a very low value to exercise all code paths in _checked_read
         f._discarded_buf_size = 8
         f.seek(126)  # skip the two first ranges
-        self.assertEqual(b'AB', f.read(2))
+        self.assertEqual(b"AB", f.read(2))
 
     def test_seek_twice_between_ranges(self):
         f = self._file
@@ -426,7 +411,7 @@ class TestRangeFileMultipleRangesQuotedBoundaries(TestRangeFileMultipleRanges):
     """Perform the same tests as TestRangeFileMultipleRanges, but uses
     an angle-bracket quoted boundary string like IIS 6.0 and 7.0
     (but not IIS 5, which breaks the RFC in a different way
-    by using square brackets, not angle brackets)
+    by using square brackets, not angle brackets).
 
     This reveals a bug caused by
 
@@ -437,10 +422,11 @@ class TestRangeFileMultipleRangesQuotedBoundaries(TestRangeFileMultipleRanges):
       in boundary lines).
 
     """
+
     # The boundary as it appears in boundary lines
     # IIS 6 and 7 use this value
     _boundary_trimmed = b"q1w2e3r4t5y6u7i8o9p0zaxscdvfbgnhmjklkl"
-    boundary = b'<' + _boundary_trimmed + b'>'
+    boundary = b"<" + _boundary_trimmed + b">"
 
     def set_file_boundary(self):
         # Emulate broken rfc822.unquote() here by removing angles
@@ -452,7 +438,7 @@ class TestRangeFileVarious(tests.TestCase):
 
     def test_seek_whence(self):
         """Test the seek whence parameter values."""
-        f = response.RangeFile('foo', BytesIO(b'abc'))
+        f = response.RangeFile("foo", BytesIO(b"abc"))
         f.set_range(0, 3)
         f.seek(0)
         f.seek(1, 1)
@@ -461,35 +447,37 @@ class TestRangeFileVarious(tests.TestCase):
 
     def test_range_syntax(self):
         """Test the Content-Range scanning."""
-
-        f = response.RangeFile('foo', BytesIO())
+        f = response.RangeFile("foo", BytesIO())
 
         def ok(expected, header_value):
             f.set_range_from_header(header_value)
             # Slightly peek under the covers to get the size
             self.assertEqual(expected, (f.tell(), f._size))
 
-        ok((1, 10), 'bytes 1-10/11')
-        ok((1, 10), 'bytes 1-10/*')
-        ok((12, 2), '\tbytes 12-13/*')
-        ok((28, 1), '  bytes 28-28/*')
-        ok((2123, 2120), 'bytes  2123-4242/12310')
-        ok((1, 10), 'bytes 1-10/ttt')  # We don't check total (ttt)
+        ok((1, 10), "bytes 1-10/11")
+        ok((1, 10), "bytes 1-10/*")
+        ok((12, 2), "\tbytes 12-13/*")
+        ok((28, 1), "  bytes 28-28/*")
+        ok((2123, 2120), "bytes  2123-4242/12310")
+        ok((1, 10), "bytes 1-10/ttt")  # We don't check total (ttt)
 
         def nok(header_value):
-            self.assertRaises(errors.InvalidHttpRange,
-                              f.set_range_from_header, header_value)
+            self.assertRaises(
+                errors.InvalidHttpRange, f.set_range_from_header, header_value
+            )
 
-        nok('bytes 10-2/3')
-        nok('chars 1-2/3')
-        nok('bytes xx-yyy/zzz')
-        nok('bytes xx-12/zzz')
-        nok('bytes 11-yy/zzz')
-        nok('bytes10-2/3')
+        nok("bytes 10-2/3")
+        nok("chars 1-2/3")
+        nok("bytes xx-yyy/zzz")
+        nok("bytes xx-12/zzz")
+        nok("bytes 11-yy/zzz")
+        nok("bytes10-2/3")
 
 
 # Taken from real request responses
-_full_text_response = (200, b"""HTTP/1.1 200 OK\r
+_full_text_response = (
+    200,
+    b"""HTTP/1.1 200 OK\r
 Date: Tue, 11 Jul 2006 04:32:56 GMT\r
 Server: Apache/2.0.54 (Fedora)\r
 Last-Modified: Sun, 23 Apr 2006 19:35:20 GMT\r
@@ -499,11 +487,15 @@ Content-Length: 35\r
 Connection: close\r
 Content-Type: text/plain; charset=UTF-8\r
 \r
-""", b"""Bazaar-NG meta directory, format 1
-""")
+""",
+    b"""Bazaar-NG meta directory, format 1
+""",
+)
 
 
-_single_range_response = (206, b"""HTTP/1.1 206 Partial Content\r
+_single_range_response = (
+    206,
+    b"""HTTP/1.1 206 Partial Content\r
 Date: Tue, 11 Jul 2006 04:45:22 GMT\r
 Server: Apache/2.0.54 (Fedora)\r
 Last-Modified: Thu, 06 Jul 2006 20:22:05 GMT\r
@@ -514,11 +506,15 @@ Content-Range: bytes 100-199/93890\r
 Connection: close\r
 Content-Type: text/plain; charset=UTF-8\r
 \r
-""", b"""mbp@sourcefrog.net-20050309040815-13242001617e4a06
-mbp@sourcefrog.net-20050309040929-eee0eb3e6d1e762""")
+""",
+    b"""mbp@sourcefrog.net-20050309040815-13242001617e4a06
+mbp@sourcefrog.net-20050309040929-eee0eb3e6d1e762""",
+)
 
 
-_single_range_no_content_type = (206, b"""HTTP/1.1 206 Partial Content\r
+_single_range_no_content_type = (
+    206,
+    b"""HTTP/1.1 206 Partial Content\r
 Date: Tue, 11 Jul 2006 04:45:22 GMT\r
 Server: Apache/2.0.54 (Fedora)\r
 Last-Modified: Thu, 06 Jul 2006 20:22:05 GMT\r
@@ -528,11 +524,15 @@ Content-Length: 100\r
 Content-Range: bytes 100-199/93890\r
 Connection: close\r
 \r
-""", b"""mbp@sourcefrog.net-20050309040815-13242001617e4a06
-mbp@sourcefrog.net-20050309040929-eee0eb3e6d1e762""")
+""",
+    b"""mbp@sourcefrog.net-20050309040815-13242001617e4a06
+mbp@sourcefrog.net-20050309040929-eee0eb3e6d1e762""",
+)
 
 
-_multipart_range_response = (206, b"""HTTP/1.1 206 Partial Content\r
+_multipart_range_response = (
+    206,
+    b"""HTTP/1.1 206 Partial Content\r
 Date: Tue, 11 Jul 2006 04:49:48 GMT\r
 Server: Apache/2.0.54 (Fedora)\r
 Last-Modified: Thu, 06 Jul 2006 20:22:05 GMT\r
@@ -542,7 +542,8 @@ Content-Length: 1534\r
 Connection: close\r
 Content-Type: multipart/byteranges; boundary=418470f848b63279b\r
 \r
-\r""", b"""--418470f848b63279b\r
+\r""",
+    b"""--418470f848b63279b\r
 Content-type: text/plain; charset=UTF-8\r
 Content-range: bytes 0-254/93890\r
 \r
@@ -579,10 +580,13 @@ mbp@sourcefrog.net-20050314025737-55eb441f430ab4ba
 mbp@sourcefrog.net-20050314025901-d74aa93bb7ee8f62
 mbp@source\r
 --418470f848b63279b--\r
-""")
+""",
+)
 
 
-_multipart_squid_range_response = (206, b"""HTTP/1.0 206 Partial Content\r
+_multipart_squid_range_response = (
+    206,
+    b"""HTTP/1.0 206 Partial Content\r
 Date: Thu, 31 Aug 2006 21:16:22 GMT\r
 Server: Apache/2.2.2 (Unix) DAV/2\r
 Last-Modified: Thu, 31 Aug 2006 17:57:06 GMT\r
@@ -594,7 +598,7 @@ X-Cache-Lookup: HIT from localhost.localdomain:3128\r
 Proxy-Connection: keep-alive\r
 \r
 """,
-                                   b"""\r
+    b"""\r
 --squid/2.5.STABLE12:C99323425AD4FE26F726261FA6C24196\r
 Content-Type: text/plain\r
 Content-Range: bytes 0-99/18672\r
@@ -611,11 +615,14 @@ com-20050708231537-2b124b835395399a :
 scott@netsplit.com-20050820234126-551311dbb7435b51 line-delta 1803 479 .scott@netsplit.com-20050820232911-dc4322a084eadf7e :
 scott@netsplit.com-20050821213706-c86\r
 --squid/2.5.STABLE12:C99323425AD4FE26F726261FA6C24196--\r
-""")
+""",
+)
 
 
 # This is made up
-_full_text_response_no_content_type = (200, b"""HTTP/1.1 200 OK\r
+_full_text_response_no_content_type = (
+    200,
+    b"""HTTP/1.1 200 OK\r
 Date: Tue, 11 Jul 2006 04:32:56 GMT\r
 Server: Apache/2.0.54 (Fedora)\r
 Last-Modified: Sun, 23 Apr 2006 19:35:20 GMT\r
@@ -624,11 +631,15 @@ Accept-Ranges: bytes\r
 Content-Length: 35\r
 Connection: close\r
 \r
-""", b"""Bazaar-NG meta directory, format 1
-""")
+""",
+    b"""Bazaar-NG meta directory, format 1
+""",
+)
 
 
-_full_text_response_no_content_length = (200, b"""HTTP/1.1 200 OK\r
+_full_text_response_no_content_length = (
+    200,
+    b"""HTTP/1.1 200 OK\r
 Date: Tue, 11 Jul 2006 04:32:56 GMT\r
 Server: Apache/2.0.54 (Fedora)\r
 Last-Modified: Sun, 23 Apr 2006 19:35:20 GMT\r
@@ -637,11 +648,15 @@ Accept-Ranges: bytes\r
 Connection: close\r
 Content-Type: text/plain; charset=UTF-8\r
 \r
-""", b"""Bazaar-NG meta directory, format 1
-""")
+""",
+    b"""Bazaar-NG meta directory, format 1
+""",
+)
 
 
-_single_range_no_content_range = (206, b"""HTTP/1.1 206 Partial Content\r
+_single_range_no_content_range = (
+    206,
+    b"""HTTP/1.1 206 Partial Content\r
 Date: Tue, 11 Jul 2006 04:45:22 GMT\r
 Server: Apache/2.0.54 (Fedora)\r
 Last-Modified: Thu, 06 Jul 2006 20:22:05 GMT\r
@@ -650,11 +665,15 @@ Accept-Ranges: bytes\r
 Content-Length: 100\r
 Connection: close\r
 \r
-""", b"""mbp@sourcefrog.net-20050309040815-13242001617e4a06
-mbp@sourcefrog.net-20050309040929-eee0eb3e6d1e762""")
+""",
+    b"""mbp@sourcefrog.net-20050309040815-13242001617e4a06
+mbp@sourcefrog.net-20050309040929-eee0eb3e6d1e762""",
+)
 
 
-_single_range_response_truncated = (206, b"""HTTP/1.1 206 Partial Content\r
+_single_range_response_truncated = (
+    206,
+    b"""HTTP/1.1 206 Partial Content\r
 Date: Tue, 11 Jul 2006 04:45:22 GMT\r
 Server: Apache/2.0.54 (Fedora)\r
 Last-Modified: Thu, 06 Jul 2006 20:22:05 GMT\r
@@ -665,15 +684,20 @@ Content-Range: bytes 100-199/93890\r
 Connection: close\r
 Content-Type: text/plain; charset=UTF-8\r
 \r
-""", b"""mbp@sourcefrog.net-20050309040815-13242001617e4a06""")
+""",
+    b"""mbp@sourcefrog.net-20050309040815-13242001617e4a06""",
+)
 
 
-_invalid_response = (444, b"""HTTP/1.1 444 Bad Response\r
+_invalid_response = (
+    444,
+    b"""HTTP/1.1 444 Bad Response\r
 Date: Tue, 11 Jul 2006 04:32:56 GMT\r
 Connection: close\r
 Content-Type: text/html; charset=iso-8859-1\r
 \r
-""", b"""<!DOCTYPE HTML PUBLIC "-//IETF//DTD HTML 2.0//EN">
+""",
+    b"""<!DOCTYPE HTML PUBLIC "-//IETF//DTD HTML 2.0//EN">
 <html><head>
 <title>404 Not Found</title>
 </head><body>
@@ -681,29 +705,35 @@ Content-Type: text/html; charset=iso-8859-1\r
 <p>I don't know what I'm doing</p>
 <hr>
 </body></html>
-""")
+""",
+)
 
 
-_multipart_no_content_range = (206, b"""HTTP/1.0 206 Partial Content\r
+_multipart_no_content_range = (
+    206,
+    b"""HTTP/1.0 206 Partial Content\r
 Content-Type: multipart/byteranges; boundary=THIS_SEPARATES\r
 Content-Length: 598\r
 \r
 """,
-                               b"""\r
+    b"""\r
 --THIS_SEPARATES\r
 Content-Type: text/plain\r
 \r
 # bzr knit index 8
 --THIS_SEPARATES\r
-""")
+""",
+)
 
 
-_multipart_no_boundary = (206, b"""HTTP/1.0 206 Partial Content\r
+_multipart_no_boundary = (
+    206,
+    b"""HTTP/1.0 206 Partial Content\r
 Content-Type: multipart/byteranges; boundary=THIS_SEPARATES\r
 Content-Length: 598\r
 \r
 """,
-                          b"""\r
+    b"""\r
 --THIS_SEPARATES\r
 Content-Type: text/plain\r
 Content-Range: bytes 0-18/18672\r
@@ -712,11 +742,11 @@ Content-Range: bytes 0-18/18672\r
 
 The range ended at the line above, this text is garbage instead of a boundary
 line
-""")
+""",
+)
 
 
 class TestHandleResponse(tests.TestCase):
-
     def _build_HTTPMessage(self, raw_headers):
         status_and_headers = BytesIO(raw_headers)
         # Get rid of the status line
@@ -729,7 +759,8 @@ class TestHandleResponse(tests.TestCase):
         code, raw_headers, body = a_response
         getheader = self._build_HTTPMessage(raw_headers)
         return response.handle_response(
-            'http://foo', code, getheader, BytesIO(a_response[2]))
+            "http://foo", code, getheader, BytesIO(a_response[2])
+        )
 
     def test_full_text(self):
         out = self.get_response(_full_text_response)
@@ -774,37 +805,46 @@ class TestHandleResponse(tests.TestCase):
         out.read(200)
 
     def test_invalid_response(self):
-        self.assertRaises(errors.InvalidHttpResponse,
-                          self.get_response, _invalid_response)
+        self.assertRaises(
+            errors.InvalidHttpResponse, self.get_response, _invalid_response
+        )
 
     def test_full_text_no_content_type(self):
         # We should not require Content-Type for a full response
         code, raw_headers, body = _full_text_response_no_content_type
         getheader = self._build_HTTPMessage(raw_headers)
-        out = response.handle_response(
-            'http://foo', code, getheader, BytesIO(body))
+        out = response.handle_response("http://foo", code, getheader, BytesIO(body))
         self.assertEqual(body, out.read())
 
     def test_full_text_no_content_length(self):
         code, raw_headers, body = _full_text_response_no_content_length
         getheader = self._build_HTTPMessage(raw_headers)
-        out = response.handle_response(
-            'http://foo', code, getheader, BytesIO(body))
+        out = response.handle_response("http://foo", code, getheader, BytesIO(body))
         self.assertEqual(body, out.read())
 
     def test_missing_content_range(self):
         code, raw_headers, body = _single_range_no_content_range
         getheader = self._build_HTTPMessage(raw_headers)
-        self.assertRaises(errors.InvalidHttpResponse,
-                          response.handle_response,
-                          'http://bogus', code, getheader, BytesIO(body))
+        self.assertRaises(
+            errors.InvalidHttpResponse,
+            response.handle_response,
+            "http://bogus",
+            code,
+            getheader,
+            BytesIO(body),
+        )
 
     def test_multipart_no_content_range(self):
         code, raw_headers, body = _multipart_no_content_range
         getheader = self._build_HTTPMessage(raw_headers)
-        self.assertRaises(errors.InvalidHttpResponse,
-                          response.handle_response,
-                          'http://bogus', code, getheader, BytesIO(body))
+        self.assertRaises(
+            errors.InvalidHttpResponse,
+            response.handle_response,
+            "http://bogus",
+            code,
+            getheader,
+            BytesIO(body),
+        )
 
     def test_multipart_no_boundary(self):
         out = self.get_response(_multipart_no_boundary)
@@ -822,23 +862,24 @@ class TestRangeFileSizeReadLimited(tests.TestCase):
         super().setUp()
         # create a test datablock larger than _max_read_size.
         chunk_size = response.RangeFile._max_read_size
-        test_pattern = b'0123456789ABCDEF'
+        test_pattern = b"0123456789ABCDEF"
         self.test_data = test_pattern * (3 * chunk_size // len(test_pattern))
         self.test_data_len = len(self.test_data)
 
     def test_max_read_size(self):
         """Read data in blocks and verify that the reads are not larger than
-           the maximum read size.
+        the maximum read size.
         """
         # retrieve data in large blocks from response.RangeFile object
         mock_read_file = FakeReadFile(self.test_data)
-        range_file = response.RangeFile('test_max_read_size', mock_read_file)
+        range_file = response.RangeFile("test_max_read_size", mock_read_file)
         response_data = range_file.read(self.test_data_len)
 
         # verify read size was equal to the maximum read size
         self.assertTrue(mock_read_file.get_max_read_size() > 0)
-        self.assertEqual(mock_read_file.get_max_read_size(),
-                         response.RangeFile._max_read_size)
+        self.assertEqual(
+            mock_read_file.get_max_read_size(), response.RangeFile._max_read_size
+        )
         self.assertEqual(mock_read_file.get_read_count(), 3)
 
         # report error if the data wasn't equal (we only report the size due
