@@ -21,16 +21,12 @@ to standard HTTP responses, single range responses and multipart range
 responses.
 """
 
-import cgi
-from io import BytesIO
-import os
-import http.client as http_client
 import email.utils as email_utils
+import http.client as http_client
+import os
+from io import BytesIO
 
-from ... import (
-    errors,
-    osutils,
-    )
+from ... import errors, osutils
 
 
 class ResponseFile:
@@ -97,8 +93,10 @@ class ResponseFile:
         if whence == os.SEEK_SET:
             if offset < self._pos:
                 raise AssertionError(
-                    "Can't seek backwards, pos: %s, offset: %s"
-                    % (self._pos, offset))
+                    "Can't seek backwards, pos: {}, offset: {}".format(
+                        self._pos, offset
+                    )
+                )
             to_discard = offset - self._pos
         elif whence == os.SEEK_CUR:
             to_discard = offset
@@ -108,6 +106,7 @@ class ResponseFile:
             # Just discard the unwanted bytes
             self.read(to_discard)
 
+
 # A RangeFile expects the following grammar (simplified to outline the
 # assumptions we rely upon).
 
@@ -156,7 +155,7 @@ class RangeFile(ResponseFile):
         self.set_range(0, -1)
 
     def set_range(self, start, size):
-        """Change the range mapping"""
+        """Change the range mapping."""
         self._start = start
         self._size = size
         # Set the new _pos since that's what we want to expose
@@ -176,35 +175,41 @@ class RangeFile(ResponseFile):
         self.read_range_definition()
 
     def read_boundary(self):
-        """Read the boundary headers defining a new range"""
-        boundary_line = b'\r\n'
-        while boundary_line == b'\r\n':
+        """Read the boundary headers defining a new range."""
+        boundary_line = b"\r\n"
+        while boundary_line == b"\r\n":
             # RFC2616 19.2 Additional CRLFs may precede the first boundary
             # string entity.
             # To be on the safe side we allow it before any boundary line
             boundary_line = self._file.readline()
 
-        if boundary_line == b'':
+        if boundary_line == b"":
             # A timeout in the proxy server caused the response to end early.
             # See launchpad bug 198646.
-            raise errors.HttpBoundaryMissing(
-                self._path,
-                self._boundary)
+            raise errors.HttpBoundaryMissing(self._path, self._boundary)
 
-        if boundary_line != b'--' + self._boundary + b'\r\n':
+        if boundary_line != b"--" + self._boundary + b"\r\n":
             # email_utils.unquote() incorrectly unquotes strings enclosed in <>
             # IIS 6 and 7 incorrectly wrap boundary strings in <>
             # together they make a beautiful bug, which we will be gracious
             # about here
-            if (self._unquote_boundary(boundary_line) !=
-                    b'--' + self._boundary + b'\r\n'):
+            if (
+                self._unquote_boundary(boundary_line)
+                != b"--" + self._boundary + b"\r\n"
+            ):
                 raise errors.InvalidHttpResponse(
                     self._path,
-                    "Expected a boundary (%s) line, got '%s'"
-                    % (self._boundary, boundary_line))
+                    "Expected a boundary ({}) line, got '{}'".format(
+                        self._boundary, boundary_line
+                    ),
+                )
 
     def _unquote_boundary(self, b):
-        return b[:2] + email_utils.unquote(b[2:-2].decode('ascii')).encode('ascii') + b[-2:]
+        return (
+            b[:2]
+            + email_utils.unquote(b[2:-2].decode("ascii")).encode("ascii")
+            + b[-2:]
+        )
 
     def read_range_definition(self):
         """Read a new range definition in a multi parts message.
@@ -214,39 +219,42 @@ class RangeFile(ResponseFile):
         """
         self._headers = http_client.parse_headers(self._file)
         # Extract the range definition
-        content_range = self._headers.get('content-range', None)
+        content_range = self._headers.get("content-range", None)
         if content_range is None:
             raise errors.InvalidHttpResponse(
                 self._path,
-                'Content-Range header missing in a multi-part response',
-                headers=self._headers)
+                "Content-Range header missing in a multi-part response",
+                headers=self._headers,
+            )
         self.set_range_from_header(content_range)
 
     def set_range_from_header(self, content_range):
-        """Helper to set the new range from its description in the headers"""
+        """Helper to set the new range from its description in the headers."""
         try:
             rtype, values = content_range.split()
         except ValueError:
-            raise errors.InvalidHttpRange(self._path, content_range,
-                                          'Malformed header')
-        if rtype != 'bytes':
-            raise errors.InvalidHttpRange(self._path, content_range,
-                                          "Unsupported range type '%s'" % rtype)
+            raise errors.InvalidHttpRange(self._path, content_range, "Malformed header")
+        if rtype != "bytes":
+            raise errors.InvalidHttpRange(
+                self._path, content_range, "Unsupported range type '{}'".format(rtype)
+            )
         try:
             # We don't need total, but note that it may be either the file size
             # or '*' if the server can't or doesn't want to return the file
             # size.
-            start_end, total = values.split('/')
-            start, end = start_end.split('-')
+            start_end, total = values.split("/")
+            start, end = start_end.split("-")
             start = int(start)
             end = int(end)
         except ValueError:
-            raise errors.InvalidHttpRange(self._path, content_range,
-                                          'Invalid range values')
+            raise errors.InvalidHttpRange(
+                self._path, content_range, "Invalid range values"
+            )
         size = end - start + 1
         if size <= 0:
-            raise errors.InvalidHttpRange(self._path, content_range,
-                                          'Invalid range, size <= 0')
+            raise errors.InvalidHttpRange(
+                self._path, content_range, "Invalid range, size <= 0"
+            )
         self.set_range(start, size)
 
     def _checked_read(self, size):
@@ -260,17 +268,18 @@ class RangeFile(ResponseFile):
             data = self._file.read(min(remaining, self._discarded_buf_size))
             remaining -= len(data)
             if not data:
-                raise errors.ShortReadvError(self._path, pos, size,
-                                             size - remaining)
+                raise errors.ShortReadvError(self._path, pos, size, size - remaining)
         self._pos += size
 
     def _seek_to_next_range(self):
         # We will cross range boundaries
         if self._boundary is None:
             # If we don't have a boundary, we can't find another range
-            raise errors.InvalidRange(self._path, self._pos,
-                                      "Range (%s, %s) exhausted"
-                                      % (self._start, self._size))
+            raise errors.InvalidRange(
+                self._path,
+                self._pos,
+                "Range ({}, {}) exhausted".format(self._start, self._size),
+            )
         self.read_boundary()
         self.read_range_definition()
 
@@ -285,23 +294,28 @@ class RangeFile(ResponseFile):
         :param size:  The number of bytes to read.  Leave unspecified or pass
             -1 to read to EOF.
         """
-        if (self._size > 0
-                and self._pos == self._start + self._size):
+        if self._size > 0 and self._pos == self._start + self._size:
             if size == 0:
-                return b''
+                return b""
             else:
                 self._seek_to_next_range()
         elif self._pos < self._start:
             raise errors.InvalidRange(
-                self._path, self._pos,
-                "Can't read %s bytes before range (%s, %s)"
-                % (size, self._start, self._size))
+                self._path,
+                self._pos,
+                "Can't read {} bytes before range ({}, {})".format(
+                    size, self._start, self._size
+                ),
+            )
         if self._size > 0:
             if size > 0 and self._pos + size > self._start + self._size:
                 raise errors.InvalidRange(
-                    self._path, self._pos,
-                    "Can't read %s bytes across range (%s, %s)"
-                    % (size, self._start, self._size))
+                    self._path,
+                    self._pos,
+                    "Can't read {} bytes across range ({}, {})".format(
+                        size, self._start, self._size
+                    ),
+                )
 
         # read data from file
         buf = BytesIO()
@@ -329,16 +343,20 @@ class RangeFile(ResponseFile):
                 final_pos = self._start + self._size + offset  # offset < 0
             else:
                 raise errors.InvalidRange(
-                    self._path, self._pos,
-                    "RangeFile: can't seek from end while size is unknown")
+                    self._path,
+                    self._pos,
+                    "RangeFile: can't seek from end while size is unknown",
+                )
         else:
-            raise ValueError("Invalid value %s for whence." % whence)
+            raise ValueError("Invalid value {} for whence.".format(whence))
 
         if final_pos < self._pos:
             # Can't seek backwards
             raise errors.InvalidRange(
-                self._path, self._pos,
-                'RangeFile: trying to seek backwards to %s' % final_pos)
+                self._path,
+                self._pos,
+                "RangeFile: trying to seek backwards to {}".format(final_pos),
+            )
 
         if self._size > 0:
             cur_limit = self._start + self._size
@@ -383,16 +401,22 @@ def handle_response(url, code, getheader, data):
         # being of type 'application/octet-stream' as per RFC2616 section
         # 7.2.1.
         # Therefore it is obviously not multipart
-        content_type = getheader('content-type', 'application/octet-stream')
-        mimetype, options = cgi.parse_header(content_type)
-        if mimetype == 'multipart/byteranges':
-            rfile.set_boundary(options['boundary'].encode('ascii'))
+        content_type = getheader("content-type", "application/octet-stream")
+        from email.message import EmailMessage
+
+        msg = EmailMessage()
+        msg["content-type"] = content_type
+        params = msg["content-type"].params
+        mimetype = msg.get_content_type()
+        if mimetype == "multipart/byteranges":
+            rfile.set_boundary(params["boundary"].encode("ascii"))
         else:
             # A response to a range request, but not multipart
-            content_range = getheader('content-range', None)
+            content_range = getheader("content-range", None)
             if content_range is None:
                 raise errors.InvalidHttpResponse(
-                    url, 'Missing the Content-Range header in a 206 range response')
+                    url, "Missing the Content-Range header in a 206 range response"
+                )
             rfile.set_range_from_header(content_range)
     else:
         raise errors.UnexpectedHttpStatus(url, code)
