@@ -8,9 +8,9 @@
 import os
 import sys
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     # clobber me, new sys.argv[0] is the script to run.
     del sys.argv[0]
     assert not os.path.isabs(sys.argv[0]), "If you know the FQ path, just use it!"
     sys.argv[0] = os.path.join(sys.prefix, "Scripts", sys.argv[0])
-    exec(compile(open(sys.argv[0]).read(), sys.argv[0], 'exec'))
+    exec(compile(open(sys.argv[0]).read(), sys.argv[0], "exec"))
